@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -33,12 +33,12 @@
 #include "util.h"
 
 /* Converts a time_t to a string, relative to the specified timezone */
-char *
+gchar *
 timet_to_str_with_zone (time_t t, icaltimezone *zone)
 {
 	struct icaltimetype itt;
 	struct tm tm;
-	char buf[256];
+	gchar buf[256];
 
 	if (t == -1)
 		return g_strdup (_("invalid time"));
@@ -51,17 +51,17 @@ timet_to_str_with_zone (time_t t, icaltimezone *zone)
 	return g_strdup (buf);
 }
 
-char *
+gchar *
 calculate_time (time_t start, time_t end)
 {
 	time_t difference = end - start;
-	char *str;
-	int   hours, minutes;
-	char *times[4];
-	char *joined;
-	int   i;
+	gchar *str;
+	gint   hours, minutes;
+	gchar *times[4];
+	gchar *joined;
+	gint   i;
 
-        i = 0;
+	i = 0;
 	if (difference >= 3600) {
 		hours = difference / 3600;
 		difference %= 3600;
@@ -76,7 +76,7 @@ calculate_time (time_t start, time_t end)
 	}
 	if (i == 0 || difference != 0) {
 		/* TRANSLATORS: here, "second" is the time division (like "minute"), not the ordinal number (like "third") */
-		times[i++] = g_strdup_printf (ngettext("%d second", "%d seconds", difference), (int)difference);
+		times[i++] = g_strdup_printf (ngettext("%d second", "%d seconds", difference), (gint)difference);
 	}
 
 	times[i] = NULL;
