@@ -44,7 +44,6 @@
 #include <shell/e-shell.h>
 
 #include "common/authentication.h"
-#include "calendar-config.h"
 #include "comp-util.h"
 #include "ea-calendar.h"
 #include "e-cal-model-calendar.h"
@@ -62,10 +61,6 @@
 #include "goto.h"
 #include "misc.h"
 
-#define E_CALENDAR_VIEW_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_CALENDAR_VIEW, ECalendarViewPrivate))
-
 struct _ECalendarViewPrivate {
 	/* The GnomeCalendar we are associated to */
 	GnomeCalendar *calendar;
@@ -73,8 +68,8 @@ struct _ECalendarViewPrivate {
 	/* The calendar model we are monitoring */
 	ECalModel *model;
 
-	/* The default category */
 	gchar *default_category;
+	gint time_divisions;
 
 	GtkTargetList *copy_target_list;
 	GtkTargetList *paste_target_list;
@@ -84,7 +79,8 @@ enum {
 	PROP_0,
 	PROP_COPY_TARGET_LIST,
 	PROP_MODEL,
-	PROP_PASTE_TARGET_LIST
+	PROP_PASTE_TARGET_LIST,
+	PROP_TIME_DIVISIONS
 };
 
 /* FIXME Why are we emitting these event signals here? Can't the model just be listened to? */
@@ -165,14 +161,17 @@ static void
 calendar_view_delete_event (ECalendarView *cal_view,
                             ECalendarViewEvent *event)
 {
+	ECalModel *model;
 	ECalComponent *comp;
 	ECalComponentVType vtype;
-	gboolean  delete = FALSE;
+	gboolean delete = TRUE;
 	GError *error = NULL;
 
 	if (!is_comp_data_valid (event))
 		return;
 
+	model = e_calendar_view_get_model (cal_view);
+
 	comp = e_cal_component_new ();
 	e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (event->comp_data->icalcomp));
 	vtype = e_cal_component_get_vtype (comp);
@@ -211,8 +210,9 @@ calendar_view_delete_event (ECalendarView *cal_view,
 				}
 			}
 		}
-	} else
-		delete = delete_component_dialog (comp, FALSE, 1, vtype, GTK_WIDGET (cal_view));
+	} else if (e_cal_model_get_confirm_delete (model))
+		delete = delete_component_dialog (
+			comp, FALSE, 1, vtype, GTK_WIDGET (cal_view));
 
 	if (delete) {
 		const gchar *uid;
@@ -267,6 +267,12 @@ calendar_view_set_property (GObject *object,
 				E_CALENDAR_VIEW (object),
 				g_value_get_object (value));
 			return;
+
+		case PROP_TIME_DIVISIONS:
+			e_calendar_view_set_time_divisions (
+				E_CALENDAR_VIEW (object),
+				g_value_get_int (value));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -296,6 +302,12 @@ calendar_view_get_property (GObject *object,
 				value, e_calendar_view_get_paste_target_list (
 				E_CALENDAR_VIEW (object)));
 			return;
+
+		case PROP_TIME_DIVISIONS:
+			g_value_set_int (
+				value, e_calendar_view_get_time_divisions (
+				E_CALENDAR_VIEW (object)));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -306,7 +318,7 @@ calendar_view_dispose (GObject *object)
 {
 	ECalendarViewPrivate *priv;
 
-	priv = E_CALENDAR_VIEW_GET_PRIVATE (object);
+	priv = E_CALENDAR_VIEW (object)->priv;
 
 	if (priv->model != NULL) {
 		g_signal_handlers_disconnect_matched (
@@ -335,7 +347,7 @@ calendar_view_finalize (GObject *object)
 {
 	ECalendarViewPrivate *priv;
 
-	priv = E_CALENDAR_VIEW_GET_PRIVATE (object);
+	priv = E_CALENDAR_VIEW (object)->priv;
 
 	g_free (priv->default_category);
 
@@ -352,8 +364,7 @@ calendar_view_constructed (GObject *object)
 	e_extensible_load_extensions (E_EXTENSIBLE (object));
 
 	/* Chain up to parent's constructed() method. */
-	if (G_OBJECT_CLASS (e_calendar_view_parent_class)->constructed)
-		G_OBJECT_CLASS (e_calendar_view_parent_class)->constructed (object);
+	G_OBJECT_CLASS (e_calendar_view_parent_class)->constructed (object);
 }
 
 static void
@@ -625,11 +636,11 @@ clipboard_get_calendar_data (ECalendarView *cal_view,
 	if (!text || !*text)
 		return;
 
-	icalcomp = icalparser_parse_string ((const gchar *) text);
+	icalcomp = icalparser_parse_string (text);
 	if (!icalcomp)
 		return;
 
-	default_zone = calendar_config_get_icaltimezone ();
+	default_zone = e_cal_model_get_timezone (cal_view->priv->model);
 	client = e_cal_model_get_default_client (cal_view->priv->model);
 
 	/* check the type of the component */
@@ -797,6 +808,18 @@ e_calendar_view_class_init (ECalendarViewClass *class)
 		PROP_PASTE_TARGET_LIST,
 		"paste-target-list");
 
+	g_object_class_install_property (
+		object_class,
+		PROP_TIME_DIVISIONS,
+		g_param_spec_int (
+			"time-divisions",
+			"Time Divisions",
+			NULL,
+			G_MININT,
+			G_MAXINT,
+			30,
+			G_PARAM_READWRITE));
+
 	signals[POPUP_EVENT] = g_signal_new (
 		"popup-event",
 		G_TYPE_FROM_CLASS (class),
@@ -879,7 +902,7 @@ e_calendar_view_class_init (ECalendarViewClass *class)
 	binding_set = gtk_binding_set_by_class (class);
 
 	gtk_binding_entry_add_signal (
-		binding_set, GDK_o, GDK_CONTROL_MASK, "open-event", 0);
+		binding_set, GDK_KEY_o, GDK_CONTROL_MASK, "open-event", 0);
 
 	/* init the accessibility support for e_day_view */
 	e_cal_view_a11y_init ();
@@ -890,7 +913,11 @@ e_calendar_view_init (ECalendarView *calendar_view)
 {
 	GtkTargetList *target_list;
 
-	calendar_view->priv = E_CALENDAR_VIEW_GET_PRIVATE (calendar_view);
+	calendar_view->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		calendar_view, E_TYPE_CALENDAR_VIEW, ECalendarViewPrivate);
+
+	/* Set this early to avoid a divide-by-zero during init. */
+	calendar_view->priv->time_divisions = 30;
 
 	target_list = gtk_target_list_new (NULL, 0);
 	e_target_list_add_calendar_targets (target_list, 0);
@@ -968,7 +995,7 @@ e_calendar_view_add_event (ECalendarView *cal_view, ECal *client, time_t dtstart
 			/* copy & paste from top canvas to main canvas */
 			gint time_divisions;
 
-			time_divisions = calendar_config_get_time_divisions ();
+			time_divisions = e_calendar_view_get_time_divisions (cal_view);
 			ic_dur = icaldurationtype_from_int (time_divisions * 60);
 		}
 
@@ -981,9 +1008,10 @@ e_calendar_view_add_event (ECalendarView *cal_view, ECal *client, time_t dtstart
 	case GNOME_CAL_MONTH_VIEW:
 	case GNOME_CAL_LIST_VIEW:
 		if (old_dtstart.is_date && old_dtend.is_date
-			&& memcmp (&ic_dur, &ic_oneday, sizeof(ic_dur)) == 0)
+			&& memcmp (&ic_dur, &ic_oneday, sizeof (ic_dur)) == 0) {
 			all_day_event = TRUE;
-		else {
+			new_dtstart = dtstart;
+		} else {
 			icaltimetype new_time = icaltime_from_timet_with_zone (dtstart, FALSE, default_zone);
 
 			new_time.hour = old_dtstart.hour;
@@ -1133,6 +1161,25 @@ e_calendar_view_get_paste_target_list (ECalendarView *cal_view)
 	return cal_view->priv->paste_target_list;
 }
 
+gint
+e_calendar_view_get_time_divisions (ECalendarView *cal_view)
+{
+	g_return_val_if_fail (E_IS_CALENDAR_VIEW (cal_view), 0);
+
+	return cal_view->priv->time_divisions;
+}
+
+void
+e_calendar_view_set_time_divisions (ECalendarView *cal_view,
+                                    gint time_divisions)
+{
+	g_return_if_fail (E_IS_CALENDAR_VIEW (cal_view));
+
+	cal_view->priv->time_divisions = time_divisions;
+
+	g_object_notify (G_OBJECT (cal_view), "time-divisions");
+}
+
 GList *
 e_calendar_view_get_selected_events (ECalendarView *cal_view)
 {
@@ -1210,12 +1257,15 @@ void
 e_calendar_view_delete_selected_occurrence (ECalendarView *cal_view)
 {
 	GList *selected;
+	ECalModel *model;
 	ECalComponent *comp;
 	ECalendarViewEvent *event;
 	ECalComponentVType vtype;
-	gboolean  delete = FALSE;
+	gboolean delete = TRUE;
 	GError *error = NULL;
 
+	model = e_calendar_view_get_model (cal_view);
+
 	selected = e_calendar_view_get_selected_events (cal_view);
 	if (!selected)
 		return;
@@ -1255,8 +1305,9 @@ e_calendar_view_delete_selected_occurrence (ECalendarView *cal_view)
 				}
 			}
 		}
-	} else
-		delete = delete_component_dialog (comp, FALSE, 1, vtype, GTK_WIDGET (cal_view));
+	} else if (e_cal_model_get_confirm_delete (model))
+		delete = delete_component_dialog (
+			comp, FALSE, 1, vtype, GTK_WIDGET (cal_view));
 
 	if (delete) {
 		const gchar *uid;
@@ -1275,7 +1326,7 @@ e_calendar_view_delete_selected_occurrence (ECalendarView *cal_view)
 			e_cal_get_timezone (event->comp_data->client, dt.tzid, &zone, &error);
 			if (error) {
 				zone = e_calendar_view_get_timezone (cal_view);
-				g_clear_error(&error);
+				g_clear_error (&error);
 			}
 		} else
 			zone = e_calendar_view_get_timezone (cal_view);
@@ -1334,8 +1385,7 @@ e_calendar_view_open_event (ECalendarView *cal_view)
 	if (selected) {
 		ECalendarViewEvent *event = (ECalendarViewEvent *) selected->data;
 		if (event && is_comp_data_valid (event))
-			e_calendar_view_edit_appointment (cal_view, event->comp_data->client,
-					event->comp_data->icalcomp, icalcomponent_get_first_property(event->comp_data->icalcomp, ICAL_ATTENDEE_PROPERTY) != NULL);
+			e_calendar_view_edit_appointment (cal_view, event->comp_data->client, event->comp_data->icalcomp, EDIT_EVENT_AUTODETECT);
 
 		g_list_free (selected);
 	}
@@ -1449,10 +1499,11 @@ e_calendar_view_new_appointment_for (ECalendarView *cal_view,
 
 /**
  * e_calendar_view_new_appointment_full
- * @param cal_view: A calendar view.
- * @param all_day: Whether create all day event or not.
- * @param meeting: This is a meeting or an appointment.
- * @param no_past_date: Don't create event in past date, use actual date instead (if TRUE).
+ * @cal_view: an #ECalendarView
+ * @all_day: Whether create all day event or not.
+ * @meeting: This is a meeting or an appointment.
+ * @no_past_date: Don't create event in past date, use actual date instead
+ * (if %TRUE).
  *
  * Opens an event editor dialog for a new appointment. The appointment's
  * start and end times are set to the currently selected time range in
@@ -1463,13 +1514,19 @@ e_calendar_view_new_appointment_for (ECalendarView *cal_view,
  * to the 'day begins' from preferences in other selected day.
  */
 void
-e_calendar_view_new_appointment_full (ECalendarView *cal_view, gboolean all_day, gboolean meeting, gboolean no_past_date)
+e_calendar_view_new_appointment_full (ECalendarView *cal_view,
+                                      gboolean all_day,
+                                      gboolean meeting,
+                                      gboolean no_past_date)
 {
+	ECalModel *model;
 	time_t dtstart, dtend, now;
 	gboolean do_rounding = FALSE;
 
 	g_return_if_fail (E_IS_CALENDAR_VIEW (cal_view));
 
+	model = e_calendar_view_get_model (cal_view);
+
 	now = time (NULL);
 
 	if (!e_calendar_view_get_selected_time_range (cal_view, &dtstart, &dtend)) {
@@ -1487,7 +1544,7 @@ e_calendar_view_new_appointment_full (ECalendarView *cal_view, gboolean all_day,
 	/* time in this cases; dtstart should be a midnight in this case */
 	if (do_rounding || (!all_day && (dtend - dtstart) == (60 * 60 * 24))) {
 		struct tm local = *localtime (&now);
-		gint time_div = calendar_config_get_time_divisions ();
+		gint time_div = e_calendar_view_get_time_divisions (cal_view);
 		gint hours, mins;
 
 		if (!time_div) /* Possible if your gconf values aren't so nice */
@@ -1504,8 +1561,8 @@ e_calendar_view_new_appointment_full (ECalendarView *cal_view, gboolean all_day,
 			mins = (mins - (mins % time_div));
 		} else {
 			/* other day than today */
-			hours = calendar_config_get_day_start_hour ();
-			mins = calendar_config_get_day_start_minute ();
+			hours = e_cal_model_get_work_day_start_hour (model);
+			mins = e_cal_model_get_work_day_start_minute (model);
 		}
 
 		dtstart = dtstart + (60 * 60 * hours) + (mins * 60);
@@ -1568,16 +1625,13 @@ e_calendar_view_open_event_with_flags (ECalendarView *cal_view, ECal *client, ic
  * @cal_view: A calendar view.
  * @client: Calendar client.
  * @icalcomp: The object to be edited.
- * @meeting: Whether the appointment is a meeting or not.
+ * @mode: one of #EEditEventMode
  *
  * Opens an editor window to allow the user to edit the selected
  * object.
  */
 void
-e_calendar_view_edit_appointment (ECalendarView *cal_view,
-			     ECal *client,
-			     icalcomponent *icalcomp,
-			     gboolean meeting)
+e_calendar_view_edit_appointment (ECalendarView *cal_view, ECal *client, icalcomponent *icalcomp, EEditEventMode mode)
 {
 	guint32 flags = 0;
 
@@ -1585,7 +1639,8 @@ e_calendar_view_edit_appointment (ECalendarView *cal_view,
 	g_return_if_fail (E_IS_CAL (client));
 	g_return_if_fail (icalcomp != NULL);
 
-	if (meeting) {
+	if ((mode == EDIT_EVENT_AUTODETECT && icalcomponent_get_first_property (icalcomp, ICAL_ATTENDEE_PROPERTY) != NULL)
+	    || mode == EDIT_EVENT_FORCE_MEETING) {
 		ECalComponent *comp = e_cal_component_new ();
 		e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (icalcomp));
 		flags |= COMP_EDITOR_MEETING;
@@ -1605,6 +1660,7 @@ e_calendar_view_modify_and_send (ECalComponent *comp,
 				 gboolean new)
 {
 	gboolean only_new_attendees = FALSE;
+	e_cal_component_commit_sequence (comp);
 
 	if (e_cal_modify_object (client, e_cal_component_get_icalcomponent (comp), mod, NULL)) {
 		gboolean strip_alarms = TRUE;
@@ -1650,7 +1706,7 @@ tooltip_grab (GtkWidget *tooltip, GdkEventKey *event, ECalendarView *view)
 	if (!widget)
 		return TRUE;
 
-	gdk_keyboard_ungrab(GDK_CURRENT_TIME);
+	gdk_keyboard_ungrab (GDK_CURRENT_TIME);
 	gtk_widget_destroy (widget);
 	g_object_set_data (G_OBJECT (view), "tooltip-window", NULL);
 
@@ -1660,7 +1716,7 @@ tooltip_grab (GtkWidget *tooltip, GdkEventKey *event, ECalendarView *view)
 static gchar *
 get_label (struct icaltimetype *tt, icaltimezone *f_zone, icaltimezone *t_zone)
 {
-        struct tm tmp_tm;
+	struct tm tmp_tm;
 
 	tmp_tm = icaltimetype_to_tm_with_zone (tt, f_zone, t_zone);
 
@@ -1680,7 +1736,7 @@ e_calendar_view_move_tip (GtkWidget *widget, gint x, gint y)
 
 	screen = gtk_widget_get_screen (widget);
 
-	gtk_widget_size_request (widget, &requisition);
+	gtk_widget_get_preferred_size (widget, &requisition, NULL);
 	w = requisition.width;
 	h = requisition.height;
 
@@ -1864,7 +1920,7 @@ e_calendar_view_get_tooltips (const ECalendarViewEventData *data)
 	e_cal_component_get_organizer (newcomp, &organiser);
 	if (organiser.cn) {
 		gchar *ptr;
-		ptr = strchr(organiser.value, ':');
+		ptr = strchr (organiser.value, ':');
 
 		if (ptr) {
 			ptr++;
@@ -1916,7 +1972,7 @@ e_calendar_view_get_tooltips (const ECalendarViewEventData *data)
 	t_start = icaltime_as_timet_with_zone (*dtstart.value, zone);
 	t_end = icaltime_as_timet_with_zone (*dtend.value, zone);
 
-	tmp1 = get_label(dtstart.value, zone, default_zone);
+	tmp1 = get_label (dtstart.value, zone, default_zone);
 	tmp = calculate_time (t_start, t_end);
 
 	/* To Translators: It will display "Time: ActualStartDateAndTime (DurationOfTheMeeting)"*/
