@@ -39,14 +39,6 @@
 #include "ea-calendar.h"
 #include "e-calendar-view.h"
 #include "comp-util.h"
-#include "calendar-config.h"
-
-/* backward-compatibility cruft */
-#include "e-util/gtk-compat.h"
-
-#define E_DAY_VIEW_MAIN_ITEM_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_DAY_VIEW_MAIN_ITEM, EDayViewMainItemPrivate))
 
 struct _EDayViewMainItemPrivate {
 	EDayView *day_view;
@@ -60,7 +52,7 @@ enum {
 static gpointer parent_class;
 
 static gboolean
-can_draw_in_region (GdkRegion *draw_region, gint x, gint y, gint width, gint height)
+can_draw_in_region (cairo_region_t *draw_region, gint x, gint y, gint width, gint height)
 {
 	GdkRectangle rect;
 
@@ -71,7 +63,8 @@ can_draw_in_region (GdkRegion *draw_region, gint x, gint y, gint width, gint hei
 	rect.width = width;
 	rect.height = height;
 
-	return gdk_region_rect_in (draw_region, &rect) != GDK_OVERLAP_RECTANGLE_OUT;
+	return cairo_region_contains_rectangle (draw_region, &rect) !=
+		CAIRO_REGION_OVERLAP_OUT;
 }
 
 static gboolean
@@ -91,21 +84,25 @@ icalcomp_is_transparent (icalcomponent *icalcomp)
 
 static void
 day_view_main_item_draw_long_events_in_vbars (EDayViewMainItem *main_item,
-                                              GdkDrawable *drawable,
+                                              cairo_t *cr,
                                               gint x,
                                               gint y,
                                               gint width,
                                               gint height,
-                                              GdkRegion *draw_region)
+                                              cairo_region_t *draw_region)
 {
 	EDayView *day_view;
 	EDayViewEvent *event;
+	ECalendarView *cal_view;
+	gint time_divisions;
 	gint event_num, start_day, end_day, day, bar_y1, bar_y2, grid_x;
-	cairo_t *cr = NULL;
 	GdkColor bg_color;
 
 	day_view = e_day_view_main_item_get_day_view (main_item);
 
+	cal_view = E_CALENDAR_VIEW (day_view);
+	time_divisions = e_calendar_view_get_time_divisions (cal_view);
+
 	for (event_num = 0; event_num < day_view->long_events->len; event_num++) {
 		gboolean first = TRUE;
 		event = &g_array_index (day_view->long_events, EDayViewEvent, event_num);
@@ -136,63 +133,52 @@ day_view_main_item_draw_long_events_in_vbars (EDayViewMainItem *main_item,
 			if (event->start <= day_view->day_starts[day]) {
 				bar_y1 = 0;
 			} else {
-				bar_y1 = event->start_minute * day_view->row_height / day_view->mins_per_row - y;
+				bar_y1 = event->start_minute * day_view->row_height / time_divisions - y;
 			}
 
 			if (event->end >= day_view->day_starts[day + 1]) {
 				bar_y2 = height;
 			} else {
-				bar_y2 = event->end_minute * day_view->row_height / day_view->mins_per_row - y;
+				bar_y2 = event->end_minute * day_view->row_height / time_divisions - y;
 			}
 
 			if (bar_y1 < height && bar_y2 > 0 && bar_y2 > bar_y1 && can_draw_in_region (draw_region, grid_x, bar_y1, E_DAY_VIEW_BAR_WIDTH - 2, bar_y2 - bar_y1)) {
-				if (!cr) {
-					cr = gdk_cairo_create (drawable);
-					cairo_save (cr);
-					gdk_cairo_set_source_color (cr, &day_view->colors[E_DAY_VIEW_COLOR_EVENT_BACKGROUND]);
-				}
+				cairo_save (cr);
+				gdk_cairo_set_source_color (cr, &day_view->colors[E_DAY_VIEW_COLOR_EVENT_BACKGROUND]);
 
 				if (first) {
 					first = FALSE;
 
 					if (gdk_color_parse (e_cal_model_get_color_for_component (e_calendar_view_get_model (E_CALENDAR_VIEW (day_view)), event->comp_data), &bg_color)) {
-						GdkColormap *colormap;
-
-						colormap = gtk_widget_get_colormap (GTK_WIDGET (day_view));
-						if (gdk_colormap_alloc_color (colormap, &bg_color, TRUE, TRUE)) {
-							gdk_cairo_set_source_color (cr, &bg_color);
-						}
+						gdk_cairo_set_source_color (cr, &bg_color);
 					}
 				}
 
 				cairo_rectangle (cr, grid_x, bar_y1, E_DAY_VIEW_BAR_WIDTH - 2, bar_y2 - bar_y1);
 				cairo_fill (cr);
+				cairo_restore (cr);
 			}
 		}
 	}
-
-	if (cr) {
-		cairo_restore (cr);
-		cairo_destroy (cr);
-	}
 }
 
 static void
 day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
-                                   GdkDrawable *drawable,
+                                   cairo_t *cr,
                                    gint x,
                                    gint y,
                                    gint width,
                                    gint height,
                                    gint day,
                                    gint event_num,
-                                   GdkRegion *draw_region)
+                                   cairo_region_t *draw_region)
 {
 	EDayView *day_view;
 	EDayViewEvent *event;
 	ECalModel *model;
+	ECalendarView *cal_view;
+	gint time_divisions;
 	gint item_x, item_y, item_w, item_h, bar_y1, bar_y2;
-	GdkGC *gc;
 	GdkColor bg_color;
 	ECalComponent *comp;
 	gint num_icons, icon_x, icon_y, icon_x_inc = 0, icon_y_inc = 0;
@@ -200,14 +186,10 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 	gboolean draw_reminder_icon, draw_recurrence_icon, draw_timezone_icon, draw_meeting_icon;
 	gboolean draw_attach_icon;
 	ECalComponentTransparency transparency;
-	cairo_t *cr;
 	cairo_pattern_t *pat;
-	cairo_font_options_t *font_options;
 	guint16 red, green, blue;
 	gint i;
 	gdouble radius, x0, y0, rect_height, rect_width, text_x_offset = 0.0;
-	gfloat alpha;
-	gboolean gradient;
 	gdouble cc = 65535.0;
 	gdouble date_fraction;
 	gboolean short_event = FALSE, resize_flag = FALSE, is_editing;
@@ -224,7 +206,10 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 	gint row_y;
 
 	day_view = e_day_view_main_item_get_day_view (main_item);
-	model = e_calendar_view_get_model (E_CALENDAR_VIEW (day_view));
+
+	cal_view = E_CALENDAR_VIEW (day_view);
+	model = e_calendar_view_get_model (cal_view);
+	time_divisions = e_calendar_view_get_time_divisions (cal_view);
 
 	/* If the event is currently being dragged, don't draw it. It will
 	   be drawn in the special drag items. */
@@ -243,17 +228,9 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 	if (!can_draw_in_region (draw_region, item_x, item_y, item_w, item_h))
 		return;
 
-	cr = gdk_cairo_create (drawable);
 	gdk_cairo_set_source_color (cr,
 			&day_view->colors[E_DAY_VIEW_COLOR_EVENT_VBAR]);
 
-	gc = day_view->main_gc;
-
-	gradient = calendar_config_get_display_events_gradient ();
-	alpha = calendar_config_get_display_events_alpha ();
-
-	font_options = get_font_options ();
-
 	if (!is_array_index_in_bounds (day_view->events[day], event_num))
 		return;
 
@@ -267,7 +244,7 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 	   column of the day, we might not want to paint over the vertical bar,
 	   since that is used for multiple events. But then you can't see
 	   where the event in the first column finishes. The border is drawn
-           along with the event using cairo*/
+	   along with the event using cairo*/
 
 	red = day_view->colors[E_DAY_VIEW_COLOR_EVENT_BACKGROUND].red;
 	green = day_view->colors[E_DAY_VIEW_COLOR_EVENT_BACKGROUND].green;
@@ -275,14 +252,9 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 
 	if (gdk_color_parse (e_cal_model_get_color_for_component (e_calendar_view_get_model (E_CALENDAR_VIEW (day_view)), event->comp_data),
 			     &bg_color)) {
-		GdkColormap *colormap;
-
-		colormap = gtk_widget_get_colormap (GTK_WIDGET (day_view));
-		if (gdk_colormap_alloc_color (colormap, &bg_color, TRUE, TRUE)) {
-			red = bg_color.red;
-			green = bg_color.green;
-			blue = bg_color.blue;
-			}
+		red = bg_color.red;
+		green = bg_color.green;
+		blue = bg_color.blue;
 	}
 
 	is_editing = day_view->editing_event_day == day && day_view->editing_event_num == event_num;
@@ -316,7 +288,7 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 			cairo_pattern_add_color_stop_rgba (pat, 0.25, 0, 0, 0, 0.2);
 			cairo_pattern_add_color_stop_rgba (pat, 0, 0, 0, 0, 1);
 			cairo_set_source (cr, pat);
-			cairo_arc (cr, item_x + item_w - E_DAY_VIEW_BAR_WIDTH + 5, item_y + 13.5, 8.0, 11 * M_PI / 8, M_PI / 8);
+			cairo_arc (cr, item_x + item_w - E_DAY_VIEW_BAR_WIDTH + 5, item_y + 13.5, 8.0, 11 * G_PI / 8, G_PI / 8);
 			cairo_fill (cr);
 			cairo_pattern_destroy (pat);
 
@@ -344,7 +316,7 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 			cairo_pattern_add_color_stop_rgba (pat, 0.7, 0, 0, 0, 0.2);
 			cairo_pattern_add_color_stop_rgba (pat, 0, 0, 0, 0, 1);
 			cairo_set_source (cr, pat);
-			cairo_arc (cr, item_x + E_DAY_VIEW_BAR_WIDTH + 13, item_y + item_h - 5, 12.0, 3 * M_PI / 8, 9 * M_PI / 8);
+			cairo_arc (cr, item_x + E_DAY_VIEW_BAR_WIDTH + 13, item_y + item_h - 5, 12.0, 3 * G_PI / 8, 9 * G_PI / 8);
 			cairo_fill (cr);
 			cairo_pattern_destroy (pat);
 
@@ -365,7 +337,7 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 			cairo_pattern_add_color_stop_rgba (pat, 0.8, 0, 0, 0, 0.2);
 			cairo_pattern_add_color_stop_rgba (pat, 0, 0, 0, 0, 1);
 			cairo_set_source (cr, pat);
-			cairo_arc (cr, item_x + item_w - E_DAY_VIEW_BAR_WIDTH + 1, item_y + item_h - 4.5, 12.0, 15 * M_PI / 8,  5 * M_PI / 8);
+			cairo_arc (cr, item_x + item_w - E_DAY_VIEW_BAR_WIDTH + 1, item_y + item_h - 4.5, 12.0, 15 * G_PI / 8,  5 * G_PI / 8);
 			cairo_fill (cr);
 			cairo_pattern_destroy (pat);
 
@@ -426,6 +398,9 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 			}
 			cairo_restore (cr);
 		}
+
+		item_x += 1;
+		item_y += 2;
 	}
 
 	/* Draw the background of the event with white to play with transparency */
@@ -440,7 +415,7 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 
 	draw_curved_rectangle (cr, x0, y0, rect_width, rect_height, radius);
 
-	cairo_set_source_rgba (cr, 1, 1, 1, alpha);
+	cairo_set_source_rgba (cr, 1, 1, 1, 1.0);
 	cairo_fill (cr);
 
 	cairo_restore (cr);
@@ -477,10 +452,11 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 	date_fraction = rect_height / day_view->row_height;
 	interval = event->end_minute - event->start_minute;
 
-	if ((interval/day_view->mins_per_row) >= 2)
+	if ((interval / time_divisions) >= 2)
 		short_event = FALSE;
-	else if ((interval%day_view->mins_per_row)==0) {
-		if (((event->end_minute%day_view->mins_per_row) == 0) || ((event->start_minute%day_view->mins_per_row) == 0))
+	else if ((interval % time_divisions) == 0) {
+		if (((event->end_minute % time_divisions) == 0) ||
+		    ((event->start_minute % time_divisions) == 0))
 			short_event = TRUE;
 		}
 	else
@@ -489,25 +465,20 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 	if (is_editing)
 		short_event = TRUE;
 
-	if (gradient) {
-		pat = cairo_pattern_create_linear (item_x + E_DAY_VIEW_BAR_WIDTH + 1.75, item_y + 7.75,
-							item_x + E_DAY_VIEW_BAR_WIDTH + 1.75, item_y + item_h - 7.75);
-		if (!short_event) {
-			cairo_pattern_add_color_stop_rgba (pat, 1, red/cc, green/cc, blue/cc, 0.8);
-			cairo_pattern_add_color_stop_rgba (pat, 1/(date_fraction + (rect_height/18)), red/cc, green/cc, blue/cc, 0.8);
-			cairo_pattern_add_color_stop_rgba (pat, 1/(date_fraction + (rect_height/18)), red/cc, green/cc, blue/cc, 0.4);
-			cairo_pattern_add_color_stop_rgba (pat, 1, red/cc, green/cc, blue/cc, 0.8);
-		} else {
-			cairo_pattern_add_color_stop_rgba (pat, 1, red/cc, green/cc, blue/cc, 0.8);
-			cairo_pattern_add_color_stop_rgba (pat, 0, red/cc, green/cc, blue/cc, 0.4);
-		}
-		cairo_set_source (cr, pat);
-		cairo_fill_preserve (cr);
-		cairo_pattern_destroy (pat);
+	pat = cairo_pattern_create_linear (item_x + E_DAY_VIEW_BAR_WIDTH + 1.75, item_y + 7.75,
+						item_x + E_DAY_VIEW_BAR_WIDTH + 1.75, item_y + item_h - 7.75);
+	if (!short_event) {
+		cairo_pattern_add_color_stop_rgba (pat, 1, red/cc, green/cc, blue/cc, 0.8);
+		cairo_pattern_add_color_stop_rgba (pat, 1/(date_fraction + (rect_height/18)), red/cc, green/cc, blue/cc, 0.8);
+		cairo_pattern_add_color_stop_rgba (pat, 1/(date_fraction + (rect_height/18)), red/cc, green/cc, blue/cc, 0.4);
+		cairo_pattern_add_color_stop_rgba (pat, 1, red/cc, green/cc, blue/cc, 0.8);
 	} else {
-		cairo_set_source_rgba (cr, red/cc, green/cc, blue/cc, 0.8);
-		cairo_fill_preserve (cr);
+		cairo_pattern_add_color_stop_rgba (pat, 1, red/cc, green/cc, blue/cc, 0.8);
+		cairo_pattern_add_color_stop_rgba (pat, 0, red/cc, green/cc, blue/cc, 0.4);
 	}
+	cairo_set_source (cr, pat);
+	cairo_fill_preserve (cr);
+	cairo_pattern_destroy (pat);
 
 	cairo_set_source_rgba (cr, red/cc, green/cc, blue/cc, 0.2);
 	cairo_set_line_width (cr, 0.5);
@@ -529,8 +500,8 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 
 	/* Draw the vertical colored bar showing when the appointment
 	   begins & ends. */
-	bar_y1 = event->start_minute * day_view->row_height / day_view->mins_per_row - y;
-	bar_y2 = event->end_minute * day_view->row_height / day_view->mins_per_row - y;
+	bar_y1 = event->start_minute * day_view->row_height / time_divisions - y;
+	bar_y2 = event->end_minute * day_view->row_height / time_divisions - y;
 
 	scroll_flag = bar_y2;
 
@@ -579,7 +550,6 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 				cairo_set_source_rgb (cr, 0, 0, 0);
 			else
 				cairo_set_source_rgb (cr, 1, 1, 1);
-			cairo_set_font_options (cr, font_options);
 			cairo_show_text (cr, end_regsizeime);
 			cairo_close_path (cr);
 			cairo_restore (cr);
@@ -587,9 +557,9 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 	}
 
 	if (bar_y2 > scroll_flag)
-		event->end_minute += day_view->mins_per_row;
+		event->end_minute += time_divisions;
 	else if (bar_y2 < scroll_flag)
-		event->end_minute -= day_view->mins_per_row;
+		event->end_minute -= time_divisions;
 
 	comp = e_cal_component_new ();
 	e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (event->comp_data->icalcomp));
@@ -725,8 +695,6 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 
 			#undef draw_pixbuf
 			#undef fit_in_event
-
-			gdk_gc_set_clip_mask (gc, NULL);
 		}
 
 		/* free memory */
@@ -736,9 +704,9 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 
 	if (!short_event)
 	{
-		if (event->start_minute % day_view->mins_per_row != 0
+		if (event->start_minute % time_divisions != 0
 			|| (day_view->show_event_end_times
-			&& event->end_minute % day_view->mins_per_row != 0)) {
+			&& event->end_minute % time_divisions != 0)) {
 				offset = day_view->first_hour_shown * 60
 				+ day_view->first_minute_shown;
 				show_span = TRUE;
@@ -748,7 +716,7 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 		start_minute = offset + event->start_minute;
 		end_minute = offset + event->end_minute;
 
-		format_time = (((end_minute - start_minute)/day_view->mins_per_row) >= 2) ? TRUE : FALSE;
+		format_time = (((end_minute - start_minute) / time_divisions) >= 2) ? TRUE : FALSE;
 
 		start_hour = start_minute / 60;
 		start_minute = start_minute % 60;
@@ -817,29 +785,24 @@ day_view_main_item_draw_day_event (EDayViewMainItem *main_item,
 		else
 			cairo_set_source_rgb (cr, 1, 1, 1);
 		cairo_set_font_size (cr, 14.0);
-		cairo_set_font_options (cr, font_options);
 		cairo_show_text (cr, text);
 		cairo_close_path (cr);
 		cairo_restore (cr);
 	}
 
-	if (font_options)
-		cairo_font_options_destroy (font_options);
-
 	g_free (text);
 	g_object_unref (comp);
-	cairo_destroy (cr);
 }
 
 static void
 day_view_main_item_draw_day_events (EDayViewMainItem *main_item,
-                                    GdkDrawable *drawable,
+                                    cairo_t *cr,
                                     gint x,
                                     gint y,
                                     gint width,
                                     gint height,
                                     gint day,
-                                    GdkRegion *draw_region)
+                                    cairo_region_t *draw_region)
 {
 	EDayView *day_view;
 	gint event_num;
@@ -849,29 +812,33 @@ day_view_main_item_draw_day_events (EDayViewMainItem *main_item,
 	for (event_num = 0; event_num < day_view->events[day]->len;
 	     event_num++) {
 		day_view_main_item_draw_day_event (
-			main_item, drawable, x, y, width, height,
+			main_item, cr, x, y, width, height,
 			day, event_num, draw_region);
 	}
 }
 
 static void
 day_view_main_item_draw_events_in_vbars (EDayViewMainItem *main_item,
-                                         GdkDrawable *drawable,
+                                         cairo_t *cr,
                                          gint x,
                                          gint y,
                                          gint width,
                                          gint height,
                                          gint day,
-                                         GdkRegion *draw_region)
+                                         cairo_region_t *draw_region)
 {
 	EDayView *day_view;
 	EDayViewEvent *event;
+	ECalendarView *cal_view;
+	gint time_divisions;
 	gint grid_x, event_num, bar_y, bar_h;
-	cairo_t *cr = NULL;
 	GdkColor bg_color;
 
 	day_view = e_day_view_main_item_get_day_view (main_item);
 
+	cal_view = E_CALENDAR_VIEW (day_view);
+	time_divisions = e_calendar_view_get_time_divisions (cal_view);
+
 	grid_x = day_view->day_offsets[day] + 1 - x;
 
 	/* Draw the busy times corresponding to the events in the day. */
@@ -887,8 +854,8 @@ day_view_main_item_draw_events_in_vbars (EDayViewMainItem *main_item,
 			continue;
 		}
 
-		bar_y = event->start_minute * day_view->row_height / day_view->mins_per_row;
-		bar_h = event->end_minute * day_view->row_height / day_view->mins_per_row - bar_y;
+		bar_y = event->start_minute * day_view->row_height / time_divisions;
+		bar_h = event->end_minute * day_view->row_height / time_divisions - bar_y;
 		bar_y -= y;
 
 		/* Skip it if it isn't visible. */
@@ -901,30 +868,19 @@ day_view_main_item_draw_events_in_vbars (EDayViewMainItem *main_item,
 			continue;
 		}
 
-		if (!cr) {
-			cr = gdk_cairo_create (drawable);
-			cairo_save (cr);
+		cairo_save (cr);
 
-			gdk_cairo_set_source_color (cr, &day_view->colors[E_DAY_VIEW_COLOR_EVENT_BACKGROUND]);
-		}
+		gdk_cairo_set_source_color (cr, &day_view->colors[E_DAY_VIEW_COLOR_EVENT_BACKGROUND]);
 
 		if (gdk_color_parse (e_cal_model_get_color_for_component (e_calendar_view_get_model (E_CALENDAR_VIEW (day_view)), event->comp_data), &bg_color)) {
-			GdkColormap *colormap;
-
-			colormap = gtk_widget_get_colormap (GTK_WIDGET (day_view));
-			if (gdk_colormap_alloc_color (colormap, &bg_color, TRUE, TRUE)) {
-				gdk_cairo_set_source_color (cr, &bg_color);
-			}
+			gdk_cairo_set_source_color (cr, &bg_color);
 		}
 
 		cairo_rectangle (cr, grid_x, bar_y, E_DAY_VIEW_BAR_WIDTH - 2, bar_h);
 
 		cairo_fill (cr);
-	}
 
-	if (cr) {
 		cairo_restore (cr);
-		cairo_destroy (cr);
 	}
 }
 
@@ -967,7 +923,7 @@ day_view_main_item_dispose (GObject *object)
 {
 	EDayViewMainItemPrivate *priv;
 
-	priv = E_DAY_VIEW_MAIN_ITEM_GET_PRIVATE (object);
+	priv = E_DAY_VIEW_MAIN_ITEM (object)->priv;
 
 	if (priv->day_view != NULL) {
 		g_object_unref (priv->day_view);
@@ -980,15 +936,14 @@ day_view_main_item_dispose (GObject *object)
 
 static void
 day_view_main_item_update (GnomeCanvasItem *item,
-			   gdouble *affine,
-			   ArtSVP *clip_path,
+			   const cairo_matrix_t *i2c,
 			   gint flags)
 {
 	GnomeCanvasItemClass *canvas_item_class;
 
 	/* Chain up to parent's update() method. */
 	canvas_item_class = GNOME_CANVAS_ITEM_CLASS (parent_class);
-	canvas_item_class->update (item, affine, clip_path, flags);
+	canvas_item_class->update (item, i2c, flags);
 
 	/* The item covers the entire canvas area. */
 	item->x1 = 0;
@@ -999,7 +954,7 @@ day_view_main_item_update (GnomeCanvasItem *item,
 
 static void
 day_view_main_item_draw (GnomeCanvasItem *canvas_item,
-                         GdkDrawable *drawable,
+                         cairo_t *cr,
                          gint x,
                          gint y,
                          gint width,
@@ -1007,6 +962,13 @@ day_view_main_item_draw (GnomeCanvasItem *canvas_item,
 {
 	EDayViewMainItem *main_item;
 	EDayView *day_view;
+	ECalendarView *cal_view;
+	ECalModel *model;
+	gint time_divisions;
+	gint work_day_start_hour;
+	gint work_day_start_minute;
+	gint work_day_end_hour;
+	gint work_day_end_minute;
 	gint row, row_y, grid_x1, grid_x2;
 	gint day, grid_y1, grid_y2;
 	gint work_day_start_y, work_day_end_y;
@@ -1014,26 +976,37 @@ day_view_main_item_draw (GnomeCanvasItem *canvas_item,
 	gint start_row, end_row, rect_x, rect_y, rect_width, rect_height;
 	struct icaltimetype day_start_tt, today_tt;
 	gint weekday;
-	cairo_t *cr;
 	gboolean today = FALSE;
-	GdkRegion *draw_region;
+	cairo_region_t *draw_region;
 	GdkRectangle rect;
 
-	cr = gdk_cairo_create (drawable);
-
 	main_item = E_DAY_VIEW_MAIN_ITEM (canvas_item);
 	day_view = e_day_view_main_item_get_day_view (main_item);
 	g_return_if_fail (day_view != NULL);
 
+	cal_view = E_CALENDAR_VIEW (day_view);
+	time_divisions = e_calendar_view_get_time_divisions (cal_view);
+
+	model = e_calendar_view_get_model (cal_view);
+	work_day_start_hour = e_cal_model_get_work_day_start_hour (model);
+	work_day_start_minute = e_cal_model_get_work_day_start_minute (model);
+	work_day_end_hour = e_cal_model_get_work_day_end_hour (model);
+	work_day_end_minute = e_cal_model_get_work_day_end_minute (model);
+
 	rect.x = 0;
 	rect.y = 0;
 	rect.width = width;
 	rect.height = height;
-	draw_region = gdk_region_rectangle (&rect);
+	if (rect.width > 0 && rect.height > 0)
+		draw_region = cairo_region_create_rectangle (&rect);
+	else
+		draw_region = cairo_region_create ();
 
 	/* Paint the background colors. */
-	work_day_start_y = e_day_view_convert_time_to_position (day_view, day_view->work_day_start_hour, day_view->work_day_start_minute) - y;
-	work_day_end_y = e_day_view_convert_time_to_position (day_view, day_view->work_day_end_hour, day_view->work_day_end_minute) - y;
+	work_day_start_y = e_day_view_convert_time_to_position (
+		day_view, work_day_start_hour, work_day_start_minute) - y;
+	work_day_end_y = e_day_view_convert_time_to_position (
+		day_view, work_day_end_hour, work_day_end_minute) - y;
 
 	today_tt = icaltime_from_timet_with_zone (time (NULL), FALSE,
 						  e_calendar_view_get_timezone (E_CALENDAR_VIEW (day_view)));
@@ -1177,20 +1150,20 @@ day_view_main_item_draw (GnomeCanvasItem *canvas_item,
 
 		/* Fill in the bars when the user is busy. */
 		day_view_main_item_draw_events_in_vbars (
-			main_item, drawable, x, y,
+			main_item, cr, x, y,
 			width, height, day, draw_region);
 	}
 
 	/* Fill in the vertical bars corresponding to the busy times from the
 	   long events. */
 	day_view_main_item_draw_long_events_in_vbars (
-		main_item, drawable, x, y, width, height, draw_region);
+		main_item, cr, x, y, width, height, draw_region);
 
 	/* Draw the event borders and backgrounds, and the vertical bars
 	   down the left edges. */
 	for (day = 0; day < day_view->days_shown; day++)
 		day_view_main_item_draw_day_events (
-			main_item, drawable, x, y,
+			main_item, cr, x, y,
 			width, height, day, draw_region);
 
 	if (e_day_view_marcus_bains_get_show_line (day_view)) {
@@ -1204,11 +1177,7 @@ day_view_main_item_draw (GnomeCanvasItem *canvas_item,
 				&day_view->colors[E_DAY_VIEW_COLOR_MARCUS_BAINS_LINE]);
 
 		if (day_view->marcus_bains_day_view_color && gdk_color_parse (day_view->marcus_bains_day_view_color, &mb_color)) {
-			GdkColormap *colormap;
-
-			colormap = gtk_widget_get_colormap (GTK_WIDGET (day_view));
-			if (gdk_colormap_alloc_color (colormap, &mb_color, TRUE, TRUE))
-				gdk_cairo_set_source_color (cr, &mb_color);
+			gdk_cairo_set_source_color (cr, &mb_color);
 		}
 		zone = e_calendar_view_get_timezone (E_CALENDAR_VIEW (day_view));
 		time_now = icaltime_current_time_with_zone (zone);
@@ -1222,7 +1191,7 @@ day_view_main_item_draw (GnomeCanvasItem *canvas_item,
 
 				grid_x1 = day_view->day_offsets[day] - x + E_DAY_VIEW_BAR_WIDTH;
 				grid_x2 = day_view->day_offsets[day + 1] - x - 1;
-				marcus_bains_y = (time_now.hour * 60 + time_now.minute) * day_view->row_height / day_view->mins_per_row - y;
+				marcus_bains_y = (time_now.hour * 60 + time_now.minute) * day_view->row_height / time_divisions - y;
 				cairo_set_line_width (cr, 1.5);
 				cairo_move_to (cr, grid_x1, marcus_bains_y);
 				cairo_line_to (cr, grid_x2, marcus_bains_y);
@@ -1231,25 +1200,17 @@ day_view_main_item_draw (GnomeCanvasItem *canvas_item,
 		}
 		cairo_restore (cr);
 	}
-	cairo_destroy (cr);
-	gdk_region_destroy (draw_region);
+	cairo_region_destroy (draw_region);
 }
 
-static gdouble
+static GnomeCanvasItem *
 day_view_main_item_point (GnomeCanvasItem *item,
                           gdouble x,
                           gdouble y,
                           gint cx,
-                          gint cy,
-                          GnomeCanvasItem **actual_item)
+                          gint cy)
 {
-	/* This is supposed to return the nearest item to the point
-	 * and the distance.  Since we are the only item we just return
-	 * ourself and 0 for the distance.  This is needed so that we
-	 * get button/motion events. */
-	*actual_item = item;
-
-	return 0.0;
+	return item;
 }
 
 static void
@@ -1288,7 +1249,8 @@ day_view_main_item_class_init (EDayViewMainItemClass *class)
 static void
 day_view_main_item_init (EDayViewMainItem *main_item)
 {
-	main_item->priv = E_DAY_VIEW_MAIN_ITEM_GET_PRIVATE (main_item);
+	main_item->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		main_item, E_TYPE_DAY_VIEW_MAIN_ITEM, EDayViewMainItemPrivate);
 }
 
 GType
