@@ -37,10 +37,6 @@
 #include "e-calendar-view.h"
 #include "e-day-view-top-item.h"
 
-#define E_DAY_VIEW_TOP_ITEM_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_DAY_VIEW_TOP_ITEM, EDayViewTopItemPrivate))
-
 struct _EDayViewTopItemPrivate {
 	/* The parent EDayView widget. */
 	EDayView *day_view;
@@ -61,7 +57,7 @@ static gpointer parent_class;
    the days visible on screen. */
 static void
 day_view_top_item_draw_triangle (EDayViewTopItem *top_item,
-                                 GdkDrawable *drawable,
+				 cairo_t *cr,
                                  gint x,
                                  gint y,
                                  gint w,
@@ -73,7 +69,6 @@ day_view_top_item_draw_triangle (EDayViewTopItem *top_item,
 	GdkColor bg_color;
 	GdkPoint points[3];
 	gint c1, c2;
-	cairo_t *cr;
 
 	day_view = e_day_view_top_item_get_day_view (top_item);
 
@@ -99,24 +94,13 @@ day_view_top_item_draw_triangle (EDayViewTopItem *top_item,
 	if (!is_comp_data_valid (event))
 		return;
 
-	cr = gdk_cairo_create (drawable);
-
 	cairo_save (cr);
 	/* Fill it in. */
 	if (gdk_color_parse (
 		e_cal_model_get_color_for_component (
 		e_calendar_view_get_model (E_CALENDAR_VIEW (day_view)),
 		event->comp_data), &bg_color)) {
-		GdkColormap *colormap;
-
-		colormap = gtk_widget_get_colormap (GTK_WIDGET (day_view));
-		if (gdk_colormap_alloc_color (colormap, &bg_color, TRUE, TRUE)) {
-			gdk_cairo_set_source_color (cr, &bg_color);
-		} else {
-			gdk_cairo_set_source_color (
-				cr, &day_view->colors
-				[E_DAY_VIEW_COLOR_LONG_EVENT_BACKGROUND]);
-		}
+		gdk_cairo_set_source_color (cr, &bg_color);
 	} else {
 		gdk_cairo_set_source_color (
 			cr, &day_view->colors
@@ -139,15 +123,13 @@ day_view_top_item_draw_triangle (EDayViewTopItem *top_item,
 	cairo_line_to (cr, x + w, c2);
 	cairo_stroke (cr);
 	cairo_restore (cr);
-
-	cairo_destroy (cr);
 }
 
 /* This draws one event in the top canvas. */
 static void
 day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
                                    gint event_num,
-                                   GdkDrawable *drawable,
+				   cairo_t *cr,
                                    gint x,
                                    gint y,
                                    gint width,
@@ -169,7 +151,6 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 	GSList *categories_list, *elem;
 	PangoLayout *layout;
 	GdkColor bg_color;
-	cairo_t *cr;
 	cairo_pattern_t *pat;
 	guint16 red, green, blue;
 	gdouble cc = 65535.0;
@@ -199,8 +180,6 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 	if (!is_comp_data_valid (event))
 		return;
 
-	cr = gdk_cairo_create (drawable);
-
 	style = gtk_widget_get_style (GTK_WIDGET (day_view));
 	comp = e_cal_component_new ();
 	e_cal_component_set_icalcomponent (
@@ -210,18 +189,9 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 		e_cal_model_get_color_for_component (
 		e_calendar_view_get_model (E_CALENDAR_VIEW (day_view)),
 		event->comp_data), &bg_color)) {
-		GdkColormap *colormap;
-
-		colormap = gtk_widget_get_colormap (GTK_WIDGET (day_view));
-		if (gdk_colormap_alloc_color (colormap, &bg_color, TRUE, TRUE)) {
-			red = bg_color.red;
-			green = bg_color.green;
-			blue = bg_color.blue;
-		} else {
-			red = day_view->colors[E_DAY_VIEW_COLOR_LONG_EVENT_BACKGROUND].red;
-			green = day_view->colors[E_DAY_VIEW_COLOR_LONG_EVENT_BACKGROUND].green;
-			blue = day_view->colors[E_DAY_VIEW_COLOR_LONG_EVENT_BACKGROUND].blue;
-		}
+		red = bg_color.red;
+		green = bg_color.green;
+		blue = bg_color.blue;
 	} else {
 		red = day_view->colors[E_DAY_VIEW_COLOR_LONG_EVENT_BACKGROUND].red;
 		green = day_view->colors[E_DAY_VIEW_COLOR_LONG_EVENT_BACKGROUND].green;
@@ -304,7 +274,7 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 	if (draw_start_triangle
 	    && event->start < day_view->day_starts[start_day]) {
 		day_view_top_item_draw_triangle (
-			top_item, drawable, item_x - x + 4, item_y - y,
+			top_item, cr, item_x - x + 4, item_y - y,
 			-E_DAY_VIEW_BAR_WIDTH, item_h, event_num);
 	}
 
@@ -312,7 +282,7 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 	if (draw_end_triangle
 	    && event->end > day_view->day_starts[end_day + 1]) {
 		day_view_top_item_draw_triangle (
-			top_item, drawable, item_x + item_w - 4 - x,
+			top_item, cr, item_x + item_w - 4 - x,
 			item_y - y, E_DAY_VIEW_BAR_WIDTH, item_h,
 			event_num);
 	}
@@ -322,7 +292,6 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 	if (day_view->editing_event_day == E_DAY_VIEW_LONG_EVENT
 	    && day_view->editing_event_num == event_num) {
 		g_object_unref (comp);
-		cairo_destroy (cr);
 		return;
 	}
 
@@ -336,7 +305,7 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 
 	time_width = e_day_view_get_time_string_width (day_view);
 
-        gdk_cairo_set_source_color (cr, &style->fg[GTK_STATE_NORMAL]);
+	gdk_cairo_set_source_color (cr, &style->fg[GTK_STATE_NORMAL]);
 
 	if (event->start > day_view->day_starts[start_day]) {
 		offset = day_view->first_hour_shown * 60
@@ -356,23 +325,23 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 				    display_hour, minute, suffix);
 		}
 
-                cairo_save (cr);
+		cairo_save (cr);
 
-                cairo_rectangle (cr,
-                                 item_x - x, item_y - y,
+		cairo_rectangle (cr,
+				 item_x - x, item_y - y,
 				 item_w - E_DAY_VIEW_LONG_EVENT_BORDER_WIDTH, item_h);
-                cairo_clip (cr);
+		cairo_clip (cr);
 
 		time_x = item_x + E_DAY_VIEW_LONG_EVENT_X_PAD - x;
 		if (display_hour < 10)
 			time_x += day_view->digit_width;
 
 		layout = gtk_widget_create_pango_layout (GTK_WIDGET (day_view), buffer);
-                cairo_move_to (cr,
-                               time_x,
-                               item_y + E_DAY_VIEW_LONG_EVENT_BORDER_HEIGHT +
-                               E_DAY_VIEW_LONG_EVENT_Y_PAD - y);
-                pango_cairo_show_layout (cr, layout);
+		cairo_move_to (cr,
+			       time_x,
+			       item_y + E_DAY_VIEW_LONG_EVENT_BORDER_HEIGHT +
+			       E_DAY_VIEW_LONG_EVENT_Y_PAD - y);
+		pango_cairo_show_layout (cr, layout);
 		g_object_unref (layout);
 
 		cairo_restore (cr);
@@ -413,9 +382,9 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 				time_x += day_view->digit_width;
 
 			layout = gtk_widget_create_pango_layout (GTK_WIDGET (day_view), buffer);
-                        cairo_move_to (cr,
-                                       time_x,
-                                       item_y + E_DAY_VIEW_LONG_EVENT_Y_PAD + 1 - y);
+			cairo_move_to (cr,
+				       time_x,
+				       item_y + E_DAY_VIEW_LONG_EVENT_Y_PAD + 1 - y);
 			pango_cairo_show_layout (cr, layout);
 			g_object_unref (layout);
 
@@ -485,19 +454,18 @@ day_view_top_item_draw_long_event (EDayViewTopItem *top_item,
 
 		if (icon_x <= max_icon_x) {
 			gdk_cairo_set_source_pixbuf (cr, pixbuf,
-                                                     icon_x, icon_y);
-                        cairo_rectangle (cr,
-                                         icon_x, icon_y,
+						     icon_x, icon_y);
+			cairo_rectangle (cr,
+					 icon_x, icon_y,
 					 E_DAY_VIEW_ICON_WIDTH,
 					 E_DAY_VIEW_ICON_HEIGHT);
-                        cairo_fill (cr);
+			cairo_fill (cr);
 			icon_x -= icon_x_inc;
 		}
 	}
 
 	e_cal_component_free_categories_list (categories_list);
 	g_object_unref (comp);
-	cairo_destroy (cr);
 }
 
 static void
@@ -551,7 +519,7 @@ day_view_top_item_dispose (GObject *object)
 {
 	EDayViewTopItemPrivate *priv;
 
-	priv = E_DAY_VIEW_TOP_ITEM_GET_PRIVATE (object);
+	priv = E_DAY_VIEW_TOP_ITEM (object)->priv;
 
 	if (priv->day_view != NULL) {
 		g_object_unref (priv->day_view);
@@ -582,7 +550,7 @@ day_view_top_item_update (GnomeCanvasItem *item,
 
 static void
 day_view_top_item_draw (GnomeCanvasItem *canvas_item,
-                        GdkDrawable *drawable,
+                        cairo_t *cr,
                         gint x,
                         gint y,
                         gint width,
@@ -597,7 +565,6 @@ day_view_top_item_draw (GnomeCanvasItem *canvas_item,
 	gint canvas_width, canvas_height, left_edge, day, date_width, date_x;
 	gint item_height, event_num;
 	PangoLayout *layout;
-	cairo_t *cr;
 	GdkColor bg, light, dark;
 	gboolean show_dates;
 
@@ -606,8 +573,6 @@ day_view_top_item_draw (GnomeCanvasItem *canvas_item,
 	g_return_if_fail (day_view != NULL);
 	show_dates = top_item->priv->show_dates;
 
-	cr = gdk_cairo_create (drawable);
-
 	style = gtk_widget_get_style (GTK_WIDGET (day_view));
 	gtk_widget_get_allocation (
 		GTK_WIDGET (canvas_item->canvas), &allocation);
@@ -706,21 +671,21 @@ day_view_top_item_draw (GnomeCanvasItem *canvas_item,
 				clip_rect.width = day_view->day_widths[day];
 			clip_rect.height = item_height - 2;
 
-                        cairo_save (cr);
+			cairo_save (cr);
 
-                        gdk_cairo_rectangle (cr, &clip_rect);
-                        cairo_clip (cr);
+			gdk_cairo_rectangle (cr, &clip_rect);
+			cairo_clip (cr);
 
 			layout = gtk_widget_create_pango_layout (GTK_WIDGET (day_view), buffer);
 			pango_layout_get_pixel_size (layout, &date_width, NULL);
 			date_x = day_view->day_offsets[day] + (clip_rect.width - date_width) / 2;
 
-                        gdk_cairo_set_source_color (cr, &style->fg[GTK_STATE_NORMAL]);
-                        cairo_move_to (cr, date_x - x, 3 - y);
-                        pango_cairo_show_layout (cr, layout);
+			gdk_cairo_set_source_color (cr, &style->fg[GTK_STATE_NORMAL]);
+			cairo_move_to (cr, date_x - x, 3 - y);
+			pango_cairo_show_layout (cr, layout);
 
 			g_object_unref (layout);
-                        cairo_restore (cr);
+			cairo_restore (cr);
 
 			/* Draw the lines down the left and right of the date cols. */
 			if (day != 0) {
@@ -760,12 +725,10 @@ day_view_top_item_draw (GnomeCanvasItem *canvas_item,
 		/* Draw the long events. */
 		for (event_num = 0; event_num < day_view->long_events->len; event_num++) {
 			day_view_top_item_draw_long_event (
-				top_item, event_num, drawable,
+				top_item, event_num, cr,
 				x, y, width, height);
 		}
 	}
-
-	cairo_destroy (cr);
 }
 
 static GnomeCanvasItem *
@@ -821,7 +784,8 @@ day_view_top_item_class_init (EDayViewTopItemClass *class)
 static void
 day_view_top_item_init (EDayViewTopItem *top_item)
 {
-	top_item->priv = E_DAY_VIEW_TOP_ITEM_GET_PRIVATE (top_item);
+	top_item->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		top_item, E_TYPE_DAY_VIEW_TOP_ITEM, EDayViewTopItemPrivate);
 }
 
 GType
