@@ -19,25 +19,19 @@
 
 #include <string.h>
 #include <glib/gi18n-lib.h>
-#include <camel/camel-internet-address.h>
 #include <libedataserverui/e-name-selector.h>
 
-#include "e-util/e-binding.h"
-#include "e-util/gconf-bridge.h"
-#include "widgets/misc/e-signature-combo-box.h"
+#include <shell/e-shell.h>
+#include <e-util/gconf-bridge.h>
+#include <misc/e-signature-combo-box.h>
 
+#include "e-msg-composer.h"
 #include "e-composer-private.h"
 #include "e-composer-from-header.h"
 #include "e-composer-name-header.h"
 #include "e-composer-post-header.h"
 #include "e-composer-text-header.h"
 
-extern gboolean composer_lite;
-
-#define E_COMPOSER_HEADER_TABLE_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_COMPOSER_HEADER_TABLE, EComposerHeaderTablePrivate))
-
 #define HEADER_TOOLTIP_TO \
 	_("Enter the recipients of the message")
 #define HEADER_TOOLTIP_CC \
@@ -58,6 +52,7 @@ enum {
 	PROP_DESTINATIONS_TO,
 	PROP_POST_TO,
 	PROP_REPLY_TO,
+	PROP_SHELL,
 	PROP_SIGNATURE,
 	PROP_SIGNATURE_LIST,
 	PROP_SUBJECT
@@ -69,10 +64,13 @@ struct _EComposerHeaderTablePrivate {
 	GtkWidget *signature_label;
 	GtkWidget *signature_combo_box;
 	ENameSelector *name_selector;
-	GtkHBox *actions_container;
+	EShell *shell;
 };
 
-static gpointer parent_class;
+G_DEFINE_TYPE (
+	EComposerHeaderTable,
+	e_composer_header_table,
+	GTK_TYPE_TABLE)
 
 static void
 g_value_set_destinations (GValue *value,
@@ -159,11 +157,7 @@ composer_header_table_notify_header (EComposerHeader *header,
 {
 	GtkWidget *parent;
 
-	if (composer_lite && strcmp (property_name, "destinations-to") == 0)
-		parent = g_object_get_data (
-			G_OBJECT (header->input_widget), "parent");
-	else
-		parent = gtk_widget_get_parent (header->input_widget);
+	parent = gtk_widget_get_parent (header->input_widget);
 	g_return_if_fail (E_IS_COMPOSER_HEADER_TABLE (parent));
 	g_object_notify (G_OBJECT (parent), property_name);
 }
@@ -172,9 +166,13 @@ static void
 composer_header_table_notify_widget (GtkWidget *widget,
                                      const gchar *property_name)
 {
+	EShell *shell;
 	GtkWidget *parent;
 
-	if (composer_lite) {
+	/* FIXME Pass this in somehow. */
+	shell = e_shell_get_default ();
+
+	if (e_shell_get_small_screen_mode (shell)) {
 		parent = gtk_widget_get_parent (widget);
 		parent = g_object_get_data (G_OBJECT (parent), "pdata");
 	} else
@@ -250,7 +248,7 @@ composer_header_table_update_destinations (EDestination **old_destinations,
 		}
 	}
 
-	camel_object_unref (inet_address);
+	g_object_unref (inet_address);
 
 skip_auto:
 
@@ -282,6 +280,27 @@ skip_custom:
 	return new_destinations;
 }
 
+static gboolean
+from_header_should_be_visible (EComposerHeaderTable *table)
+{
+	EShell *shell;
+	EComposerHeader *header;
+	EComposerHeaderType type;
+	EAccountComboBox *combo_box;
+
+	shell = e_composer_header_table_get_shell (table);
+
+	/* Always display From in standard mode. */
+	if (!e_shell_get_express_mode (shell))
+		return TRUE;
+
+	type = E_COMPOSER_HEADER_FROM;
+	header = e_composer_header_table_get_header (table, type);
+	combo_box = E_ACCOUNT_COMBO_BOX (header->input_widget);
+
+	return (e_account_combo_box_count_displayed_accounts (combo_box) > 1);
+}
+
 static void
 composer_header_table_setup_mail_headers (EComposerHeaderTable *table)
 {
@@ -294,6 +313,8 @@ composer_header_table_setup_mail_headers (EComposerHeaderTable *table)
 		EComposerHeader *header;
 		const gchar *key;
 		guint binding_id;
+		gboolean sensitive;
+		gboolean visible;
 
 		binding_id = table->priv->gconf_bindings[ii];
 		header = e_composer_header_table_get_header (table, ii);
@@ -310,10 +331,6 @@ composer_header_table_setup_mail_headers (EComposerHeaderTable *table)
 				key = COMPOSER_GCONF_PREFIX "/show_mail_cc";
 				break;
 
-			case E_COMPOSER_HEADER_FROM:
-				key = COMPOSER_GCONF_PREFIX "/show_mail_from";
-				break;
-
 			case E_COMPOSER_HEADER_REPLY_TO:
 				key = COMPOSER_GCONF_PREFIX "/show_mail_reply_to";
 				break;
@@ -324,22 +341,29 @@ composer_header_table_setup_mail_headers (EComposerHeaderTable *table)
 		}
 
 		switch (ii) {
+			case E_COMPOSER_HEADER_FROM:
+				sensitive = TRUE;
+				visible = from_header_should_be_visible (table);
+				break;
+
 			case E_COMPOSER_HEADER_BCC:
 			case E_COMPOSER_HEADER_CC:
-			case E_COMPOSER_HEADER_FROM:
 			case E_COMPOSER_HEADER_REPLY_TO:
 			case E_COMPOSER_HEADER_SUBJECT:
 			case E_COMPOSER_HEADER_TO:
-				e_composer_header_set_sensitive (header, TRUE);
-				e_composer_header_set_visible (header, TRUE);
+				sensitive = TRUE;
+				visible = TRUE;
 				break;
 
 			default:
-				e_composer_header_set_sensitive (header, FALSE);
-				e_composer_header_set_visible (header, FALSE);
+				sensitive = FALSE;
+				visible = FALSE;
 				break;
 		}
 
+		e_composer_header_set_sensitive (header, sensitive);
+		e_composer_header_set_visible (header, visible);
+
 		if (key != NULL)
 			binding_id = gconf_bridge_bind_property (
 				bridge, key, G_OBJECT (header), "visible");
@@ -449,6 +473,7 @@ composer_header_table_from_changed_cb (EComposerHeaderTable *table)
 		composer_header_table_update_destinations (
 		old_destinations, always_cc ? account->cc_addrs : NULL);
 	e_composer_header_table_set_destinations_cc (table, new_destinations);
+	e_destination_freev (old_destinations);
 	e_destination_freev (new_destinations);
 
 	/* Update automatic BCC destinations. */
@@ -458,6 +483,7 @@ composer_header_table_from_changed_cb (EComposerHeaderTable *table)
 		composer_header_table_update_destinations (
 		old_destinations, always_bcc ? account->bcc_addrs : NULL);
 	e_composer_header_table_set_destinations_bcc (table, new_destinations);
+	e_destination_freev (old_destinations);
 	e_destination_freev (new_destinations);
 
 	/* XXX We should NOT be checking specific account types here.
@@ -482,6 +508,16 @@ composer_header_table_from_changed_cb (EComposerHeaderTable *table)
 		composer_header_table_setup_mail_headers (table);
 }
 
+static void
+composer_header_table_set_shell (EComposerHeaderTable *table,
+                                 EShell *shell)
+{
+	g_return_if_fail (E_IS_SHELL (shell));
+	g_return_if_fail (table->priv->shell == NULL);
+
+	table->priv->shell = g_object_ref (shell);
+}
+
 static GObject *
 composer_header_table_constructor (GType type,
                                    guint n_construct_properties,
@@ -490,12 +526,17 @@ composer_header_table_constructor (GType type,
 	GObject *object;
 	EComposerHeaderTablePrivate *priv;
 	guint rows, ii;
+	gint row_padding;
+	gboolean small_screen_mode;
 
 	/* Chain up to parent's constructor() method. */
-	object = G_OBJECT_CLASS (parent_class)->constructor (
+	object = G_OBJECT_CLASS (
+		e_composer_header_table_parent_class)->constructor (
 		type, n_construct_properties, construct_properties);
 
-	priv = E_COMPOSER_HEADER_TABLE_GET_PRIVATE (object);
+	priv = E_COMPOSER_HEADER_TABLE (object)->priv;
+
+	small_screen_mode = e_shell_get_small_screen_mode (priv->shell);
 
 	rows = G_N_ELEMENTS (priv->headers);
 	gtk_table_resize (GTK_TABLE (object), rows, 4);
@@ -505,45 +546,19 @@ composer_header_table_constructor (GType type,
 	/* Use "ypadding" instead of "row-spacing" because some rows may
 	 * be invisible and we don't want spacing around them. */
 
+	/* For small screens, pack the table's rows closely together. */
+	row_padding = small_screen_mode ? 0 : 3;
+
 	for (ii = 0; ii < rows; ii++) {
 		gtk_table_attach (
 			GTK_TABLE (object), priv->headers[ii]->title_widget,
-			0, 1, ii, ii + 1, GTK_FILL, GTK_FILL, 0, 3);
-		if (composer_lite && ii == E_COMPOSER_HEADER_TO) {
-			GtkWidget *box = gtk_hbox_new (FALSE, 0);
-			g_object_set_data (
-				G_OBJECT (priv->headers[ii]->input_widget),
-				"parent", object);
-			gtk_box_pack_start (
-				GTK_BOX (box), priv->headers[ii]->input_widget,
-				TRUE, TRUE, 3);
-			gtk_box_pack_start (
-				GTK_BOX (box),
-				GTK_WIDGET (priv->actions_container),
-				FALSE, FALSE, 0);
-			gtk_widget_show (box);
-			gtk_table_attach (
-				GTK_TABLE (object), box, 1, 4, ii, ii + 1,
-				GTK_FILL | GTK_EXPAND, 0, 0, 3);
-
-		} else {
-			gtk_table_attach (
-				GTK_TABLE (object),
-				priv->headers[ii]->input_widget, 1, 4,
-				ii, ii + 1, GTK_FILL | GTK_EXPAND, 0, 0, 3);
-		}
-		if (composer_lite && priv->headers[ii]->action_widget) {
-			/* Pack the widgets to the end. Helps formatting
-			 * when hiding the From field. */
-			gtk_box_pack_end (
-				GTK_BOX (priv->actions_container),
-				priv->headers[ii]->action_widget,
-				FALSE, FALSE, 6);
-		}
+			0, 1, ii, ii + 1, GTK_FILL, GTK_FILL, 0, row_padding);
+		gtk_table_attach (
+			GTK_TABLE (object),
+			priv->headers[ii]->input_widget, 1, 4,
+			ii, ii + 1, GTK_FILL | GTK_EXPAND, 0, 0, row_padding);
 	}
 
-	if (composer_lite)
-		gtk_widget_show_all ((GtkWidget *)priv->actions_container);
 	ii = E_COMPOSER_HEADER_FROM;
 
 	/* Leave room in the "From" row for signature stuff. */
@@ -552,22 +567,24 @@ composer_header_table_constructor (GType type,
 		priv->headers[ii]->input_widget,
 		"right-attach", 2, NULL);
 
-	e_binding_new (
+	g_object_bind_property (
 		priv->headers[ii]->input_widget, "visible",
-		priv->signature_label, "visible");
+		priv->signature_label, "visible",
+		G_BINDING_SYNC_CREATE);
 
-	e_binding_new (
+	g_object_bind_property (
 		priv->headers[ii]->input_widget, "visible",
-		priv->signature_combo_box, "visible");
+		priv->signature_combo_box, "visible",
+		G_BINDING_SYNC_CREATE);
 
 	/* Now add the signature stuff. */
-	if (!composer_lite) {
+	if (!small_screen_mode) {
 		gtk_table_attach (
 			GTK_TABLE (object), priv->signature_label,
-			2, 3, ii, ii + 1, 0, 0, 0, 3);
+			2, 3, ii, ii + 1, 0, 0, 0, row_padding);
 		gtk_table_attach (
 			GTK_TABLE (object), priv->signature_combo_box,
-			3, 4, ii, ii + 1, composer_lite ? GTK_FILL: 0, 0, 0, 3);
+			3, 4, ii, ii + 1, 0, 0, 0, row_padding);
 	} else {
 		GtkWidget *box = gtk_hbox_new (FALSE, 0);
 
@@ -580,7 +597,7 @@ composer_header_table_constructor (GType type,
 		g_object_set_data (G_OBJECT (box), "pdata", object);
 		gtk_table_attach (
 			GTK_TABLE (object), box,
-			3, 4, ii, ii + 1, GTK_FILL, 0, 0, 3);
+			3, 4, ii, ii + 1, GTK_FILL, 0, 0, row_padding);
 		gtk_widget_hide (box);
 	}
 
@@ -653,6 +670,12 @@ composer_header_table_set_property (GObject *object,
 				g_value_get_string (value));
 			return;
 
+		case PROP_SHELL:
+			composer_header_table_set_shell (
+				E_COMPOSER_HEADER_TABLE (object),
+				g_value_get_object (value));
+			return;
+
 		case PROP_SIGNATURE:
 			e_composer_header_table_set_signature (
 				E_COMPOSER_HEADER_TABLE (object),
@@ -745,6 +768,13 @@ composer_header_table_get_property (GObject *object,
 				E_COMPOSER_HEADER_TABLE (object)));
 			return;
 
+		case PROP_SHELL:
+			g_value_set_object (
+				value,
+				e_composer_header_table_get_shell (
+				E_COMPOSER_HEADER_TABLE (object)));
+			return;
+
 		case PROP_SIGNATURE:
 			g_value_set_object (
 				value,
@@ -776,7 +806,7 @@ composer_header_table_dispose (GObject *object)
 	EComposerHeaderTablePrivate *priv;
 	gint ii;
 
-	priv = E_COMPOSER_HEADER_TABLE_GET_PRIVATE (object);
+	priv = E_COMPOSER_HEADER_TABLE (object)->priv;
 
 	for (ii = 0; ii < G_N_ELEMENTS (priv->headers); ii++) {
 		if (priv->headers[ii] != NULL) {
@@ -795,17 +825,21 @@ composer_header_table_dispose (GObject *object)
 		priv->name_selector = NULL;
 	}
 
+	if (priv->shell != NULL) {
+		g_object_unref (priv->shell);
+		priv->shell = NULL;
+	}
+
 	/* Chain up to parent's dispose() method. */
-	G_OBJECT_CLASS (parent_class)->dispose (object);
+	G_OBJECT_CLASS (e_composer_header_table_parent_class)->dispose (object);
 }
 
 static void
-composer_header_table_class_init (EComposerHeaderTableClass *class)
+e_composer_header_table_class_init (EComposerHeaderTableClass *class)
 {
 	GObjectClass *object_class;
 	GParamSpec *element_spec;
 
-	parent_class = g_type_class_peek_parent (class);
 	g_type_class_add_private (class, sizeof (EComposerHeaderTablePrivate));
 
 	object_class = G_OBJECT_CLASS (class);
@@ -910,6 +944,17 @@ composer_header_table_class_init (EComposerHeaderTableClass *class)
 			NULL,
 			G_PARAM_READWRITE));
 
+	g_object_class_install_property (
+		object_class,
+		PROP_SHELL,
+		g_param_spec_object (
+			"shell",
+			NULL,
+			NULL,
+			E_TYPE_SHELL,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT_ONLY));
+
 	g_object_class_install_property (
 		object_class,
 		PROP_SIGNATURE,
@@ -942,21 +987,21 @@ composer_header_table_class_init (EComposerHeaderTableClass *class)
 }
 
 static void
-composer_header_table_init (EComposerHeaderTable *table)
+e_composer_header_table_init (EComposerHeaderTable *table)
 {
 	EComposerHeader *header;
 	ENameSelector *name_selector;
 	GtkWidget *widget;
 	gint ii;
 
-	table->priv = E_COMPOSER_HEADER_TABLE_GET_PRIVATE (table);
+	table->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		table, E_TYPE_COMPOSER_HEADER_TABLE,
+		EComposerHeaderTablePrivate);
 
 	name_selector = e_name_selector_new ();
 	table->priv->name_selector = name_selector;
 
-	table->priv->actions_container = (GtkHBox *)gtk_hbox_new (FALSE, 6);
-
-	header = e_composer_from_header_new_with_action (_("Fr_om:"), _("From"));
+	header = e_composer_from_header_new (_("Fr_om:"));
 	composer_header_table_bind_header ("account", "changed", header);
 	composer_header_table_bind_header ("account-list", "refreshed", header);
 	composer_header_table_bind_header ("account-name", "changed", header);
@@ -965,24 +1010,21 @@ composer_header_table_init (EComposerHeaderTable *table)
 		composer_header_table_from_changed_cb), table);
 	table->priv->headers[E_COMPOSER_HEADER_FROM] = header;
 
-	header = e_composer_text_header_new_label (_("_Reply-To:"), "");
+	header = e_composer_text_header_new_label (_("_Reply-To:"));
 	composer_header_table_bind_header ("reply-to", "changed", header);
 	table->priv->headers[E_COMPOSER_HEADER_REPLY_TO] = header;
 
-	header = e_composer_name_header_new_with_label (
-		_("_To:"), name_selector);
+	header = e_composer_name_header_new (_("_To:"), name_selector);
 	e_composer_header_set_input_tooltip (header, HEADER_TOOLTIP_TO);
 	composer_header_table_bind_header ("destinations-to", "changed", header);
 	table->priv->headers[E_COMPOSER_HEADER_TO] = header;
 
-	header = e_composer_name_header_new_with_action (
-		_("_Cc:"), _("CC"), name_selector);
+	header = e_composer_name_header_new (_("_Cc:"), name_selector);
 	e_composer_header_set_input_tooltip (header, HEADER_TOOLTIP_CC);
 	composer_header_table_bind_header ("destinations-cc", "changed", header);
 	table->priv->headers[E_COMPOSER_HEADER_CC] = header;
 
-	header = e_composer_name_header_new_with_action (
-		_("_Bcc:"), _("BCC"), name_selector);
+	header = e_composer_name_header_new (_("_Bcc:"), name_selector);
 	e_composer_header_set_input_tooltip (header, HEADER_TOOLTIP_BCC);
 	composer_header_table_bind_header ("destinations-bcc", "changed", header);
 	table->priv->headers[E_COMPOSER_HEADER_BCC] = header;
@@ -991,7 +1033,7 @@ composer_header_table_init (EComposerHeaderTable *table)
 	composer_header_table_bind_header ("post-to", "changed", header);
 	table->priv->headers[E_COMPOSER_HEADER_POST_TO] = header;
 
-	header = e_composer_text_header_new_label (_("S_ubject:"), NULL);
+	header = e_composer_text_header_new_label (_("S_ubject:"));
 	composer_header_table_bind_header ("subject", "changed", header);
 	table->priv->headers[E_COMPOSER_HEADER_SUBJECT] = header;
 
@@ -1009,45 +1051,33 @@ composer_header_table_init (EComposerHeaderTable *table)
 	 *     make the title_widget and input_widget members private. */
 	for (ii = 0; ii < E_COMPOSER_NUM_HEADERS; ii++) {
 		header = table->priv->headers[ii];
-		e_binding_new (
+		g_object_bind_property (
 			header, "visible",
-			header->title_widget, "visible");
-		e_binding_new (
+			header->title_widget, "visible",
+			G_BINDING_SYNC_CREATE);
+		g_object_bind_property (
 			header, "visible",
-			header->input_widget, "visible");
+			header->input_widget, "visible",
+			G_BINDING_SYNC_CREATE);
 	}
 }
 
-GType
-e_composer_header_table_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0)) {
-		static const GTypeInfo type_info = {
-			sizeof (EComposerHeaderTableClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) composer_header_table_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,  /* class_data */
-			sizeof (EComposerHeaderTable),
-			0,     /* n_preallocs */
-			(GInstanceInitFunc) composer_header_table_init,
-			NULL   /* value_table */
-		};
-
-		type = g_type_register_static (
-			GTK_TYPE_TABLE, "EComposerHeaderTable", &type_info, 0);
-	}
-
-	return type;
-}
-
 GtkWidget *
-e_composer_header_table_new (void)
+e_composer_header_table_new (EShell *shell)
 {
-	return g_object_new (E_TYPE_COMPOSER_HEADER_TABLE, NULL);
+	g_return_val_if_fail (E_IS_SHELL (shell), NULL);
+
+	return g_object_new (
+		E_TYPE_COMPOSER_HEADER_TABLE,
+		"shell", shell, NULL);
+}
+
+EShell *
+e_composer_header_table_get_shell (EComposerHeaderTable *table)
+{
+	g_return_val_if_fail (E_IS_COMPOSER_HEADER_TABLE (table), NULL);
+
+	return table->priv->shell;
 }
 
 EComposerHeader *
