@@ -20,6 +20,9 @@
 #include "e-composer-private.h"
 #include "e-util/e-util-private.h"
 
+/* Initial height of the picture gallery. */
+#define GALLERY_INITIAL_HEIGHT 150
+
 static void
 composer_setup_charset_menu (EMsgComposer *composer)
 {
@@ -110,7 +113,8 @@ msg_composer_url_requested_cb (GtkHTML *html,
 	array = g_byte_array_new ();
 	camel_stream = camel_stream_mem_new_with_byte_array (array);
 	wrapper = camel_medium_get_content (CAMEL_MEDIUM (mime_part));
-	camel_data_wrapper_decode_to_stream (wrapper, camel_stream, NULL);
+	camel_data_wrapper_decode_to_stream_sync (
+		wrapper, camel_stream, NULL, NULL);
 
 	gtk_html_write (html, stream, (gchar *) array->data, array->len);
 
@@ -123,12 +127,37 @@ msg_composer_url_requested_cb (GtkHTML *html,
 	g_signal_stop_emission_by_name (html, "url-requested");
 }
 
+static void
+composer_update_gallery_visibility (EMsgComposer *composer)
+{
+	GtkhtmlEditor *editor;
+	GtkToggleAction *toggle_action;
+	gboolean gallery_active;
+	gboolean html_mode;
+
+	editor = GTKHTML_EDITOR (composer);
+	html_mode = gtkhtml_editor_get_html_mode (editor);
+
+	toggle_action = GTK_TOGGLE_ACTION (ACTION (PICTURE_GALLERY));
+	gallery_active = gtk_toggle_action_get_active (toggle_action);
+
+	if (html_mode && gallery_active) {
+		gtk_widget_show (composer->priv->gallery_scrolled_window);
+		gtk_widget_show (composer->priv->gallery_icon_view);
+	} else {
+		gtk_widget_hide (composer->priv->gallery_scrolled_window);
+		gtk_widget_hide (composer->priv->gallery_icon_view);
+	}
+}
+
 void
 e_composer_private_constructed (EMsgComposer *composer)
 {
 	EMsgComposerPrivate *priv = composer->priv;
-	EShell *shell;
 	EFocusTracker *focus_tracker;
+	EShell *shell;
+	EShellSettings *shell_settings;
+	EWebView *web_view;
 	GtkhtmlEditor *editor;
 	GtkUIManager *ui_manager;
 	GtkAction *action;
@@ -136,26 +165,30 @@ e_composer_private_constructed (EMsgComposer *composer)
 	GtkWidget *widget;
 	GtkWidget *send_widget;
 	GtkWindow *window;
-	GtkHTML *html;
 	const gchar *path;
-	gchar *filename;
+	gboolean small_screen_mode;
+	gchar *filename, *gallery_path;
 	gint ii;
 	GError *error = NULL;
 
 	editor = GTKHTML_EDITOR (composer);
-	html = gtkhtml_editor_get_html (editor);
 	ui_manager = gtkhtml_editor_get_ui_manager (editor);
 
-	shell = e_shell_get_default ();
+	shell = e_msg_composer_get_shell (composer);
+	shell_settings = e_shell_get_shell_settings (shell);
+	web_view = e_msg_composer_get_web_view (composer);
+	small_screen_mode = e_shell_get_small_screen_mode (shell);
 
-	if (e_msg_composer_get_lite ()) {
+	if (small_screen_mode) {
 #if 0
-		/* In the lite composer, for small screens, we are not ready yet
-		 * to hide the menubar.  It still has useful items like the ones
-		 * to show/hide the various header fields, plus the security options.
+		/* In the lite composer, for small screens, we are not
+		 * ready yet to hide the menubar.  It still has useful
+		 * items like the ones to show/hide the various header
+		 * fields, plus the security options.
 		 *
-		 * When we move those options out of the menu and into the composer's
-		 * toplevel, we can probably get rid of the menu.
+		 * When we move those options out of the menu and into
+		 * the composer's toplevel, we can probably get rid of
+		 * the menu.
 		 */
 		widget = gtkhtml_editor_get_managed_widget (editor, "/main-menu");
 		gtk_widget_hide (widget);
@@ -171,6 +204,7 @@ e_composer_private_constructed (EMsgComposer *composer)
 	priv->window_group = gtk_window_group_new ();
 	gtk_window_group_add_window (priv->window_group, window);
 
+	priv->async_actions = gtk_action_group_new ("async");
 	priv->charset_actions = gtk_action_group_new ("charset");
 	priv->composer_actions = gtk_action_group_new ("composer");
 
@@ -248,33 +282,53 @@ e_composer_private_constructed (EMsgComposer *composer)
 
 	priv->focus_tracker = focus_tracker;
 
-	/* Construct the header table. */
-
 	container = editor->vbox;
 
+	/* Construct the activity bar. */
+
+	widget = e_activity_bar_new ();
+	gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
+	priv->activity_bar = g_object_ref (widget);
+	/* EActivityBar controls its own visibility. */
+
+	/* Construct the alert bar for errors. */
+
+	widget = e_alert_bar_new ();
+	gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
+	priv->alert_bar = g_object_ref (widget);
+	/* EAlertBar controls its own visibility. */
+
+	/* Construct the header table. */
+
 	widget = e_composer_header_table_new (shell);
 	gtk_container_set_border_width (GTK_CONTAINER (widget), 6);
-	gtk_box_pack_start (GTK_BOX (editor->vbox), widget, FALSE, FALSE, 0);
-	if (e_msg_composer_get_lite ())
-		gtk_box_reorder_child (GTK_BOX (editor->vbox), widget, 1);
+	gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
+	if (small_screen_mode)
+		gtk_box_reorder_child (GTK_BOX (container), widget, 1);
 	else
-		gtk_box_reorder_child (GTK_BOX (editor->vbox), widget, 2);
+		gtk_box_reorder_child (GTK_BOX (container), widget, 2);
 
 	priv->header_table = g_object_ref (widget);
 	gtk_widget_show (widget);
 
 	/* Construct the attachment paned. */
 
-	if (e_msg_composer_get_lite ()) {
+	if (small_screen_mode) {
 		e_attachment_paned_set_default_height (75); /* short attachment bar for Anjal */
 		e_attachment_icon_view_set_default_icon_size (GTK_ICON_SIZE_BUTTON);
 	}
+
 	widget = e_attachment_paned_new ();
 	gtk_box_pack_start (GTK_BOX (container), widget, TRUE, TRUE, 0);
 	priv->attachment_paned = g_object_ref (widget);
 	gtk_widget_show (widget);
 
-	if (e_msg_composer_get_lite ()) {
+	g_object_bind_property (
+		web_view, "editable",
+		widget, "editable",
+		G_BINDING_SYNC_CREATE);
+
+	if (small_screen_mode) {
 		GtkWidget *tmp, *tmp1, *tmp_box, *container;
 		GtkWidget *combo;
 
@@ -329,18 +383,54 @@ e_composer_private_constructed (EMsgComposer *composer)
 		gtk_box_pack_end (GTK_BOX (container), tmp_box, FALSE, FALSE, 3);
 	}
 
-	g_object_set_data ((GObject *)composer, "vbox", editor->vbox);
+	container = e_attachment_paned_get_content_area (
+		E_ATTACHMENT_PANED (priv->attachment_paned));
+
+	widget = gtk_vpaned_new ();
+	gtk_container_add (GTK_CONTAINER (container), widget);
+	gtk_widget_show (widget);
+
+	container = widget;
+
+	widget = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_policy (
+		GTK_SCROLLED_WINDOW (widget),
+		GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (
+		GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_IN);
+	gtk_widget_set_size_request (widget, -1, GALLERY_INITIAL_HEIGHT);
+	gtk_paned_pack1 (GTK_PANED (container), widget, FALSE, FALSE);
+	priv->gallery_scrolled_window = g_object_ref (widget);
+	gtk_widget_show (widget);
 
 	/* Reparent the scrolled window containing the GtkHTML widget
 	 * into the content area of the top attachment pane. */
 
-	widget = GTK_WIDGET (gtkhtml_editor_get_html (editor));
+	widget = GTK_WIDGET (web_view);
 	widget = gtk_widget_get_parent (widget);
-	container = e_attachment_paned_get_content_area (
-		E_ATTACHMENT_PANED (priv->attachment_paned));
 	gtk_widget_reparent (widget, container);
-	gtk_box_set_child_packing (
-		GTK_BOX (container), widget, TRUE, TRUE, 0, GTK_PACK_START);
+
+	/* Construct the picture gallery. */
+
+	container = priv->gallery_scrolled_window;
+
+	gallery_path = e_shell_settings_get_string (
+		shell_settings, "composer-gallery-path");
+	widget = e_picture_gallery_new (gallery_path);
+	gtk_container_add (GTK_CONTAINER (container), widget);
+	priv->gallery_icon_view = g_object_ref (widget);
+	g_free (gallery_path);
+
+	g_signal_connect (
+		composer, "notify::html-mode",
+		G_CALLBACK (composer_update_gallery_visibility), NULL);
+
+	g_signal_connect_swapped (
+		ACTION (PICTURE_GALLERY), "toggled",
+		G_CALLBACK (composer_update_gallery_visibility), composer);
+
+	/* XXX What is this for? */
+	g_object_set_data (G_OBJECT (composer), "vbox", editor->vbox);
 
 	composer_setup_recent_menu (composer);
 
@@ -371,13 +461,17 @@ e_composer_private_constructed (EMsgComposer *composer)
 				continue;
 		}
 
-		e_mutual_binding_new (
+		g_object_bind_property (
 			header, "sensitive",
-			action, "sensitive");
+			action, "sensitive",
+			G_BINDING_BIDIRECTIONAL |
+			G_BINDING_SYNC_CREATE);
 
-		e_mutual_binding_new (
+		g_object_bind_property (
 			header, "visible",
-			action, "active");
+			action, "active",
+			G_BINDING_BIDIRECTIONAL |
+			G_BINDING_SYNC_CREATE);
 	}
 
 	/* Install a handler for inline images. */
@@ -392,26 +486,36 @@ e_composer_private_constructed (EMsgComposer *composer)
 	 *     switch to WebKit.  --mbarnes */
 
 	g_signal_connect (
-		html, "url-requested",
+		web_view, "url-requested",
 		G_CALLBACK (msg_composer_url_requested_cb), composer);
-
-	priv->mail_sent = FALSE;
 }
 
 void
 e_composer_private_dispose (EMsgComposer *composer)
 {
-	GConfBridge *bridge;
-	GArray *array;
-	guint binding_id;
+	if (composer->priv->gconf_bridge_binding_ids) {
+		GConfBridge *bridge;
+		GArray *array;
+		guint binding_id;
 
-	bridge = gconf_bridge_get ();
-	array = composer->priv->gconf_bridge_binding_ids;
+		bridge = gconf_bridge_get ();
+		array = composer->priv->gconf_bridge_binding_ids;
 
-	while (array->len > 0) {
-		binding_id = g_array_index (array, guint, 0);
-		gconf_bridge_unbind (bridge, binding_id);
-		g_array_remove_index_fast (array, 0);
+		while (array->len > 0) {
+			binding_id = g_array_index (array, guint, 0);
+			gconf_bridge_unbind (bridge, binding_id);
+			g_array_remove_index_fast (array, 0);
+		}
+
+		g_array_free (composer->priv->gconf_bridge_binding_ids, TRUE);
+		composer->priv->gconf_bridge_binding_ids = NULL;
+	}
+
+	if (composer->priv->shell != NULL) {
+		g_object_remove_weak_pointer (
+			G_OBJECT (composer->priv->shell),
+			&composer->priv->shell);
+		composer->priv->shell = NULL;
 	}
 
 	if (composer->priv->header_table != NULL) {
@@ -419,6 +523,16 @@ e_composer_private_dispose (EMsgComposer *composer)
 		composer->priv->header_table = NULL;
 	}
 
+	if (composer->priv->activity_bar != NULL) {
+		g_object_unref (composer->priv->activity_bar);
+		composer->priv->activity_bar = NULL;
+	}
+
+	if (composer->priv->alert_bar != NULL) {
+		g_object_unref (composer->priv->alert_bar);
+		composer->priv->alert_bar = NULL;
+	}
+
 	if (composer->priv->attachment_paned != NULL) {
 		g_object_unref (composer->priv->attachment_paned);
 		composer->priv->attachment_paned = NULL;
@@ -434,6 +548,11 @@ e_composer_private_dispose (EMsgComposer *composer)
 		composer->priv->window_group = NULL;
 	}
 
+	if (composer->priv->async_actions != NULL) {
+		g_object_unref (composer->priv->async_actions);
+		composer->priv->async_actions = NULL;
+	}
+
 	if (composer->priv->charset_actions != NULL) {
 		g_object_unref (composer->priv->charset_actions);
 		composer->priv->charset_actions = NULL;
@@ -444,6 +563,11 @@ e_composer_private_dispose (EMsgComposer *composer)
 		composer->priv->composer_actions = NULL;
 	}
 
+	if (composer->priv->gallery_scrolled_window != NULL) {
+		g_object_unref (composer->priv->gallery_scrolled_window);
+		composer->priv->gallery_scrolled_window = NULL;
+	}
+
 	g_hash_table_remove_all (composer->priv->inline_images);
 	g_hash_table_remove_all (composer->priv->inline_images_by_url);
 
@@ -690,3 +814,75 @@ e_composer_paste_uris (EMsgComposer *composer,
 
 	return TRUE;
 }
+
+gboolean
+e_composer_selection_is_image_uris (EMsgComposer *composer,
+                                    GtkSelectionData *selection)
+{
+	gboolean all_image_uris = TRUE;
+	gchar **uris;
+	guint ii;
+
+	g_return_val_if_fail (E_IS_MSG_COMPOSER (composer), FALSE);
+	g_return_val_if_fail (selection != NULL, FALSE);
+
+	uris = gtk_selection_data_get_uris (selection);
+
+	if (uris == NULL)
+		return FALSE;
+
+	for (ii = 0; uris[ii] != NULL; ii++) {
+		GFile *file;
+		GFileInfo *file_info;
+		GdkPixbufLoader *loader;
+		const gchar *attribute;
+		const gchar *content_type;
+		gchar *mime_type = NULL;
+
+		file = g_file_new_for_uri (uris[ii]);
+		attribute = G_FILE_ATTRIBUTE_STANDARD_FAST_CONTENT_TYPE;
+
+		/* XXX This blocks, but we're requesting the fast content
+		 *     type (which only inspects filenames), so hopefully
+		 *     it won't be noticeable.  Also, this is best effort
+		 *     so we don't really care if it fails. */
+		file_info = g_file_query_info (
+			file, attribute, G_FILE_QUERY_INFO_NONE, NULL, NULL);
+
+		if (file_info == NULL) {
+			g_object_unref (file);
+			all_image_uris = FALSE;
+			break;
+		}
+
+		content_type = g_file_info_get_attribute_string (
+			file_info, attribute);
+		mime_type = g_content_type_get_mime_type (content_type);
+
+		g_object_unref (file_info);
+		g_object_unref (file);
+
+		if (mime_type == NULL) {
+			all_image_uris = FALSE;
+			break;
+		}
+
+		/* Easy way to determine if a MIME type is a supported
+		 * image format: try creating a GdkPixbufLoader for it. */
+		loader = gdk_pixbuf_loader_new_with_mime_type (mime_type, NULL);
+
+		g_free (mime_type);
+
+		if (loader == NULL) {
+			all_image_uris = FALSE;
+			break;
+		}
+
+		gdk_pixbuf_loader_close (loader, NULL);
+		g_object_unref (loader);
+	}
+
+	g_strfreev (uris);
+
+	return all_image_uris;
+}
