@@ -37,10 +37,6 @@
 #include "e-cal-shell-backend.h"
 #include "e-cal-shell-content.h"
 
-#define E_CAL_SHELL_SIDEBAR_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_CAL_SHELL_SIDEBAR, ECalShellSidebarPrivate))
-
 struct _ECalShellSidebarPrivate {
 	GtkWidget *paned;
 	GtkWidget *selector;
@@ -111,6 +107,7 @@ cal_shell_sidebar_backend_died_cb (ECalShellSidebar *cal_shell_sidebar,
                                    ECal *client)
 {
 	EShellView *shell_view;
+	EShellContent *shell_content;
 	EShellSidebar *shell_sidebar;
 	GHashTable *client_table;
 	ESource *source;
@@ -120,6 +117,7 @@ cal_shell_sidebar_backend_died_cb (ECalShellSidebar *cal_shell_sidebar,
 
 	shell_sidebar = E_SHELL_SIDEBAR (cal_shell_sidebar);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
+	shell_content = e_shell_view_get_shell_content (shell_view);
 
 	source = e_cal_get_source (client);
 	uid = e_source_peek_uid (source);
@@ -129,7 +127,8 @@ cal_shell_sidebar_backend_died_cb (ECalShellSidebar *cal_shell_sidebar,
 	g_hash_table_remove (client_table, uid);
 	cal_shell_sidebar_emit_status_message (cal_shell_sidebar, NULL);
 
-	e_alert_submit (E_ALERT_SINK (e_shell_view_get_shell_content (shell_view)),
+	e_alert_submit (
+		E_ALERT_SINK (shell_content),
 		"calendar:calendar-crashed", NULL);
 
 	g_object_unref (source);
@@ -141,18 +140,23 @@ cal_shell_sidebar_backend_error_cb (ECalShellSidebar *cal_shell_sidebar,
                                     ECal *client)
 {
 	EShellView *shell_view;
+	EShellContent *shell_content;
 	EShellSidebar *shell_sidebar;
 	ESourceGroup *source_group;
 	ESource *source;
 
 	shell_sidebar = E_SHELL_SIDEBAR (cal_shell_sidebar);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
+	shell_content = e_shell_view_get_shell_content (shell_view);
 
 	source = e_cal_get_source (client);
 	source_group = e_source_peek_group (source);
 
-	e_alert_submit (E_ALERT_SINK (e_shell_view_get_shell_content (shell_view)),
-		"calendar:backend-error", e_source_group_peek_name (source_group), e_source_peek_name (source), message, NULL);
+	e_alert_submit (
+		E_ALERT_SINK (shell_content),
+		"calendar:backend-error",
+		e_source_group_peek_name (source_group),
+		e_source_peek_name (source), message, NULL);
 }
 
 static void
@@ -161,11 +165,13 @@ cal_shell_sidebar_client_opened_cb (ECalShellSidebar *cal_shell_sidebar,
                                     ECal *client)
 {
 	EShellView *shell_view;
+	EShellContent *shell_content;
 	EShellSidebar *shell_sidebar;
 	const gchar *message;
 
 	shell_sidebar = E_SHELL_SIDEBAR (cal_shell_sidebar);
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
+	shell_content = e_shell_view_get_shell_content (shell_view);
 
 	if (g_error_matches (error, E_CALENDAR_ERROR,
 		E_CALENDAR_STATUS_AUTHENTICATION_FAILED) ||
@@ -186,14 +192,16 @@ cal_shell_sidebar_client_opened_cb (ECalShellSidebar *cal_shell_sidebar,
 			return;
 
 		case E_CALENDAR_STATUS_REPOSITORY_OFFLINE:
-			e_alert_submit (E_ALERT_SINK (e_shell_view_get_shell_content (shell_view)),
+			e_alert_submit (
+				E_ALERT_SINK (shell_content),
 				"calendar:prompt-no-contents-offline-calendar",
 				NULL);
 			/* fall through */
 
 		default:
 			if (error->code != E_CALENDAR_STATUS_REPOSITORY_OFFLINE) {
-				e_alert_submit (E_ALERT_SINK (e_shell_view_get_shell_content (shell_view)),
+				e_alert_submit (
+					E_ALERT_SINK (shell_content),
 					"calendar:failed-open-calendar",
 					error->message, NULL);
 			}
@@ -222,13 +230,15 @@ cal_shell_sidebar_default_loaded_cb (ESource *source,
                                      EShellSidebar *shell_sidebar)
 {
 	ECalShellSidebarPrivate *priv;
+	EShellContent *shell_content;
 	EShellView *shell_view;
 	ECal *client;
 	GError *error = NULL;
 
-	priv = E_CAL_SHELL_SIDEBAR_GET_PRIVATE (shell_sidebar);
+	priv = E_CAL_SHELL_SIDEBAR (shell_sidebar)->priv;
 
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
+	shell_content = e_shell_view_get_shell_content (shell_view);
 
 	client = e_load_cal_source_finish (source, result, &error);
 
@@ -237,7 +247,8 @@ cal_shell_sidebar_default_loaded_cb (ESource *source,
 		goto exit;
 
 	} else if (error != NULL) {
-		e_alert_submit (E_ALERT_SINK (e_shell_view_get_shell_content (shell_view)),
+		e_alert_submit (
+			E_ALERT_SINK (shell_content),
 			"calendar:failed-open-calendar",
 			error->message, NULL);
 		g_error_free (error);
@@ -325,15 +336,8 @@ cal_shell_sidebar_row_changed_cb (ECalShellSidebar *cal_shell_sidebar,
 	ESourceSelector *selector;
 	ESource *source;
 
-	/* XXX ESourceSelector's underlying tree store has only one
-	 *     column: ESource objects.  While we're not supposed to
-	 *     know this, listening for "row-changed" signals from
-	 *     the model is easier to deal with than the selector's
-	 *     "selection-changed" signal, which doesn't tell you
-	 *     _which_ row changed. */
-
 	selector = e_cal_shell_sidebar_get_selector (cal_shell_sidebar);
-	gtk_tree_model_get (tree_model, tree_iter, 0, &source, -1);
+	source = e_source_selector_get_source_by_path (selector, tree_path);
 
 	/* XXX This signal gets emitted a lot while the model is being
 	 *     rebuilt, during which time we won't get a valid ESource.
@@ -412,7 +416,7 @@ cal_shell_sidebar_restore_state_cb (EShellWindow *shell_window,
 	GObject *object;
 	const gchar *key;
 
-	priv = E_CAL_SHELL_SIDEBAR_GET_PRIVATE (shell_sidebar);
+	priv = E_CAL_SHELL_SIDEBAR (shell_sidebar)->priv;
 
 	shell = e_shell_window_get_shell (shell_window);
 	shell_settings = e_shell_get_shell_settings (shell);
@@ -514,7 +518,7 @@ cal_shell_sidebar_dispose (GObject *object)
 {
 	ECalShellSidebarPrivate *priv;
 
-	priv = E_CAL_SHELL_SIDEBAR_GET_PRIVATE (object);
+	priv = E_CAL_SHELL_SIDEBAR (object)->priv;
 
 	if (priv->paned != NULL) {
 		g_object_unref (priv->paned);
@@ -553,7 +557,7 @@ cal_shell_sidebar_finalize (GObject *object)
 {
 	ECalShellSidebarPrivate *priv;
 
-	priv = E_CAL_SHELL_SIDEBAR_GET_PRIVATE (object);
+	priv = E_CAL_SHELL_SIDEBAR (object)->priv;
 
 	g_hash_table_destroy (priv->client_table);
 
@@ -563,14 +567,12 @@ cal_shell_sidebar_finalize (GObject *object)
 
 static void
 new_calendar_clicked (GtkButton *button,
-		      EShellSidebar *shell_sidebar)
+                      EShellSidebar *shell_sidebar)
 {
 	EShellView *shell_view;
 	EShellWindow *shell_window;
-	EShellBackend *shell_backend;
 
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
-	shell_backend = e_shell_view_get_shell_backend (shell_view);
 	shell_window = e_shell_view_get_shell_window (shell_view);
 
 	calendar_setup_new_calendar (GTK_WINDOW (shell_window));
@@ -592,7 +594,7 @@ cal_shell_sidebar_constructed (GObject *object)
 	GtkWidget *widget;
 	AtkObject *a11y;
 
-	priv = E_CAL_SHELL_SIDEBAR_GET_PRIVATE (object);
+	priv = E_CAL_SHELL_SIDEBAR (object)->priv;
 
 	/* Chain up to parent's constructed() method. */
 	G_OBJECT_CLASS (parent_class)->constructed (object);
@@ -744,6 +746,7 @@ cal_shell_sidebar_client_removed (ECalShellSidebar *cal_shell_sidebar,
 
 	source = e_cal_get_source (client);
 	uid = e_source_peek_uid (source);
+	g_return_if_fail (uid != NULL);
 
 	g_hash_table_remove (client_table, uid);
 	e_source_selector_unselect_source (selector, source);
@@ -842,8 +845,9 @@ cal_shell_sidebar_init (ECalShellSidebar *cal_shell_sidebar)
 		(GDestroyNotify) g_free,
 		(GDestroyNotify) g_object_unref);
 
-	cal_shell_sidebar->priv =
-		E_CAL_SHELL_SIDEBAR_GET_PRIVATE (cal_shell_sidebar);
+	cal_shell_sidebar->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		cal_shell_sidebar, E_TYPE_CAL_SHELL_SIDEBAR,
+		ECalShellSidebarPrivate);
 
 	cal_shell_sidebar->priv->client_table = client_table;
 
