@@ -157,7 +157,9 @@ action_mail_create_search_folder_cb (GtkAction *action,
 	reader = E_MAIL_READER (mail_view);
 	folder_uri = e_mail_reader_get_folder_uri (reader);
 
-	search_rule = vfolder_clone_rule (search_rule);
+	search_rule = vfolder_clone_rule (session, search_rule);
+	g_return_if_fail (search_rule != NULL);
+
 	rule_name = g_strdup_printf ("%s %s", search_rule->name, search_text);
 	e_filter_rule_set_source (search_rule, E_FILTER_SOURCE_INCOMING);
 	e_filter_rule_set_name (search_rule, rule_name);
@@ -255,8 +257,10 @@ action_mail_folder_expunge_cb (GtkAction *action,
 {
 	EMailShellSidebar *mail_shell_sidebar;
 	EMFolderTree *folder_tree;
+	EShellBackend *shell_backend;
 	EShellWindow *shell_window;
 	EShellView *shell_view;
+	EMailSession *session;
 	CamelFolder *folder;
 
 	/* This handles both the "folder-expunge" and "account-expunge"
@@ -276,7 +280,10 @@ action_mail_folder_expunge_cb (GtkAction *action,
 	folder = em_folder_tree_get_selected_folder (folder_tree);
 	g_return_if_fail (folder != NULL);
 
-	em_utils_expunge_folder (GTK_WIDGET (shell_window), e_mail_backend_get_session (E_MAIL_BACKEND (e_shell_view_get_shell_backend (shell_view))), folder);
+	shell_backend = e_shell_view_get_shell_backend (shell_view);
+	session = e_mail_backend_get_session (E_MAIL_BACKEND (shell_backend));
+
+	em_utils_expunge_folder (GTK_WIDGET (shell_window), session, folder);
 }
 
 static void
@@ -374,6 +381,7 @@ action_mail_folder_new_cb (GtkAction *action,
 {
 	EShellView *shell_view;
 	EShellWindow *shell_window;
+	EMailSession *session;
 	EMailShellSidebar *mail_shell_sidebar;
 	CamelFolderInfo *folder_info;
 	EMFolderTree *folder_tree;
@@ -384,10 +392,13 @@ action_mail_folder_new_cb (GtkAction *action,
 	mail_shell_sidebar = mail_shell_view->priv->mail_shell_sidebar;
 	folder_tree = e_mail_shell_sidebar_get_folder_tree (mail_shell_sidebar);
 	folder_info = em_folder_tree_get_selected_folder_info (folder_tree);
+	session = em_folder_tree_get_session (folder_tree);
 	g_return_if_fail (folder_info != NULL);
 
 	em_folder_utils_create_folder (
-		folder_info, folder_tree, GTK_WINDOW (shell_window));
+		folder_info, folder_tree, session,
+		GTK_WINDOW (shell_window));
+
 	camel_folder_info_free (folder_info);
 }
 
@@ -716,21 +727,27 @@ action_mail_label_none_cb (GtkAction *action,
 }
 
 static void
-action_mail_send_receive_cb (GtkAction *action, EMailShellView *mail_shell_view)
+action_mail_send_receive_cb (GtkAction *action,
+                             EMailShellView *mail_shell_view)
 {
-	e_mail_shell_view_send_receive (mail_shell_view, E_MAIL_SEND_RECEIVE_BOTH, NULL);
+	e_mail_shell_view_send_receive (
+		mail_shell_view, E_MAIL_SEND_RECEIVE_BOTH, NULL);
 }
 
 static void
-action_mail_send_receive_receive_all_cb (GtkAction *action, EMailShellView *mail_shell_view)
+action_mail_send_receive_receive_all_cb (GtkAction *action,
+                                         EMailShellView *mail_shell_view)
 {
-	e_mail_shell_view_send_receive (mail_shell_view, E_MAIL_SEND_RECEIVE_RECEIVE, NULL);
+	e_mail_shell_view_send_receive (
+		mail_shell_view, E_MAIL_SEND_RECEIVE_RECEIVE, NULL);
 }
 
 static void
-action_mail_send_receive_send_all_cb (GtkAction *action, EMailShellView *mail_shell_view)
+action_mail_send_receive_send_all_cb (GtkAction *action,
+                                      EMailShellView *mail_shell_view)
 {
-	e_mail_shell_view_send_receive (mail_shell_view, E_MAIL_SEND_RECEIVE_SEND, NULL);
+	e_mail_shell_view_send_receive (
+		mail_shell_view, E_MAIL_SEND_RECEIVE_SEND, NULL);
 }
 
 static void
@@ -1817,6 +1834,7 @@ e_mail_shell_view_update_popup_labels (EMailShellView *mail_shell_view)
 	/* Unmerge the previous menu items. */
 	gtk_ui_manager_remove_ui (ui_manager, merge_id);
 	e_action_group_remove_all_actions (action_group);
+	gtk_ui_manager_ensure_update (ui_manager);
 
 	mail_shell_content = mail_shell_view->priv->mail_shell_content;
 	mail_view = e_mail_shell_content_get_mail_view (mail_shell_content);
