@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -49,19 +49,17 @@ struct _proxyDialogClass {
 	GObjectClass parent_class;
 };
 
-
 GType proxy_dialog_get_type (void);
 proxyDialog *proxy_dialog_new (void);
-void proxy_commit(GtkWidget *button, EConfigHookItemFactoryData *data);
 GtkWidget * org_gnome_proxy (EPlugin *epl, EConfigHookItemFactoryData *data);
 static void proxy_add_account (GtkWidget *button, EAccount *account);
 static void proxy_remove_account (GtkWidget *button, EAccount *account);
 static void proxy_update_tree_view (EAccount *account);
-static void proxy_cancel(GtkWidget *button, EAccount *account);
+static void proxy_cancel (GtkWidget *button, EAccount *account);
 static void proxy_edit_account (GtkWidget *button, EAccount *account);
 void proxy_abort (GtkWidget *button, EConfigHookItemFactoryData *data);
 void proxy_commit (GtkWidget *button, EConfigHookItemFactoryData *data);
 static void proxy_setup_meta_tree_view (EAccount *account);
-static proxyHandler *proxy_get_item_from_list (EAccount *account, char *account_name);
+static proxyHandler *proxy_get_item_from_list (EAccount *account, gchar *account_name);
 static void proxy_load_edit_dialog (EAccount *account, proxyHandler *edited);
 void free_proxy_list (GList *proxy_list);
