@@ -41,7 +41,6 @@
 #include <mail/e-mail-browser.h>
 #include <mail/em-utils.h>
 #include <mail/em-format-html.h>
-#include <mail/mail-config.h>
 #include <mail/message-list.h>
 #include <e-util/e-account-utils.h>
 #include <e-util/e-dialog-utils.h>
@@ -203,7 +202,7 @@ set_description (ECalComponent *comp, CamelMimeMessage *message)
 
 	byte_array = g_byte_array_new ();
 	stream = camel_stream_mem_new_with_byte_array (byte_array);
-	camel_data_wrapper_decode_to_stream (content, stream, NULL);
+	camel_data_wrapper_decode_to_stream_sync (content, stream, NULL, NULL);
 	str = g_strndup ((gchar *) byte_array->data, byte_array->len);
 	g_object_unref (stream);
 
@@ -324,7 +323,7 @@ set_attachments (ECal *client, ECalComponent *comp, CamelMimeMessage *message)
 	e_cal_component_get_uid (comp, &comp_uid);
 	local_store = e_cal_get_local_attachment_store (client);
 	path = g_build_path ("/", local_store, comp_uid, NULL);
-	
+
 	destination = g_file_new_for_path (path);
 	g_free (path);
 
@@ -385,6 +384,7 @@ set_attachments (ECal *client, ECalComponent *comp, CamelMimeMessage *message)
 	/* XXX Does this take ownership of the list? */
 	e_cal_component_set_attachment_list (comp, uri_list);
 
+	e_attachment_store_remove_all (store);
 	g_object_unref (destination);
 	g_object_unref (store);
 }
@@ -780,7 +780,10 @@ do_mail_to_event (AsyncData *data)
 			struct _manage_comp *mc;
 
 			/* retrieve the message from the CamelFolder */
-			message = camel_folder_get_message (folder, g_ptr_array_index (uids, i), NULL);
+			/* FIXME Not passing a GCancellable or GError. */
+			message = camel_folder_get_message_sync (
+				folder, g_ptr_array_index (uids, i),
+				NULL, NULL);
 			if (!message) {
 				continue;
 			}
