@@ -41,10 +41,6 @@
 #include "e-shell-searchbar.h"
 #include "e-shell-window-actions.h"
 
-#define E_SHELL_VIEW_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_SHELL_VIEW, EShellViewPrivate))
-
 #define SIMPLE_SEARCHBAR_WIDTH 300
 #define STATE_SAVE_TIMEOUT_SECONDS 3
 
@@ -247,7 +243,7 @@ shell_view_save_state_done_cb (GFile *file,
 }
 
 static EActivity *
-shell_view_save_state (EShellView *shell_view)
+shell_view_save_state (EShellView *shell_view, gboolean immediately)
 {
 	EShellBackend *shell_backend;
 	SaveStateData *data;
@@ -266,6 +262,15 @@ shell_view_save_state (EShellView *shell_view)
 	g_return_val_if_fail (contents != NULL, NULL);
 
 	path = g_build_filename (config_dir, "state.ini", NULL);
+	if (immediately) {
+		g_file_set_contents (path, contents, -1, NULL);
+
+		g_free (path);
+		g_free (contents);
+
+		return NULL;
+	}
+
 	file = g_file_new_for_path (path);
 	g_free (path);
 
@@ -301,7 +306,7 @@ shell_view_state_timeout_cb (EShellView *shell_view)
 	if (shell_view->priv->state_save_activity != NULL)
 		return TRUE;
 
-	activity = shell_view_save_state (shell_view);
+	activity = shell_view_save_state (shell_view, FALSE);
 
 	/* Set up a weak pointer that gets set to NULL when the
 	 * activity finishes.  This will tell us if we're still
@@ -489,14 +494,14 @@ shell_view_dispose (GObject *object)
 {
 	EShellViewPrivate *priv;
 
-	priv = E_SHELL_VIEW_GET_PRIVATE (object);
+	priv = E_SHELL_VIEW (object)->priv;
 
 	/* Expedite any pending state saves. */
 	if (priv->state_save_timeout_id > 0) {
 		g_source_remove (priv->state_save_timeout_id);
 		priv->state_save_timeout_id = 0;
 		if (priv->state_save_activity == NULL)
-			shell_view_save_state (E_SHELL_VIEW (object));
+			shell_view_save_state (E_SHELL_VIEW (object), TRUE);
 	}
 
 	if (priv->state_save_activity != NULL) {
@@ -546,7 +551,7 @@ shell_view_finalize (GObject *object)
 {
 	EShellViewPrivate *priv;
 
-	priv = E_SHELL_VIEW_GET_PRIVATE (object);
+	priv = E_SHELL_VIEW (object)->priv;
 
 	g_key_file_free (priv->state_key_file);
 
@@ -1073,7 +1078,8 @@ e_shell_view_init (EShellView *shell_view,
 
 	size_group = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
 
-	shell_view->priv = E_SHELL_VIEW_GET_PRIVATE (shell_view);
+	shell_view->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		shell_view, E_TYPE_SHELL_VIEW, EShellViewPrivate);
 	shell_view->priv->state_key_file = g_key_file_new ();
 	shell_view->priv->size_group = size_group;
 }
