@@ -27,10 +27,16 @@
 #include <string.h>
 #include <glib/gi18n.h>
 
+#include <gconf/gconf-client.h>
+
 #include <e-util/e-util.h>
-#include <e-util/e-binding.h>
+#include <e-util/e-util-private.h>
+#include <e-util/e-alert-dialog.h>
+#include <e-util/e-alert-sink.h>
+#include <e-util/e-extensible.h>
 #include <e-util/e-plugin-ui.h>
 #include <e-util/gconf-bridge.h>
+#include <widgets/misc/e-alert-bar.h>
 #include <widgets/misc/e-import-assistant.h>
 #include <widgets/misc/e-menu-tool-button.h>
 #include <widgets/misc/e-online-button.h>
@@ -41,10 +47,7 @@
 #include <e-shell-view.h>
 #include <e-shell-switcher.h>
 #include <e-shell-window-actions.h>
-
-#define E_SHELL_WINDOW_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_SHELL_WINDOW, EShellWindowPrivate))
+#include <e-shell-utils.h>
 
 /* Shorthand, requires a variable named "shell_window". */
 #define ACTION(name) \
@@ -61,7 +64,8 @@
 /* Format for switcher action names.
  * The last part is the shell view name.
  * (e.g. switch-to-mail, switch-to-calendar) */
-#define SWITCHER_FORMAT		"switch-to-%s"
+#define E_SHELL_SWITCHER_FORMAT   "switch-to-%s"
+#define E_SHELL_NEW_WINDOW_FORMAT "new-%s-window"
 
 G_BEGIN_DECLS
 
@@ -83,6 +87,7 @@ struct _EShellWindowPrivate {
 
 	/*** Widgetry ***/
 
+	GtkWidget *alert_bar;
 	GtkWidget *content_pane;
 	GtkWidget *content_notebook;
 	GtkWidget *sidebar_notebook;
@@ -91,6 +96,7 @@ struct _EShellWindowPrivate {
 	GtkWidget *status_notebook;
 
 	/* Miscellaneous */
+	GtkWidget *menubar_box;
 
 	/* Shell signal handlers. */
 	GArray *signal_handler_ids;
