@@ -43,10 +43,6 @@
 #include <e-util/e-extensible.h>
 #include "e-calendar.h"
 
-#define E_DATE_EDIT_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_DATE_EDIT, EDateEditPrivate))
-
 struct _EDateEditPrivate {
 	GtkWidget *date_entry;
 	GtkWidget *date_button;
@@ -455,7 +451,8 @@ e_date_edit_class_init (EDateEditClass *class)
 static void
 e_date_edit_init (EDateEdit *dedit)
 {
-	dedit->priv = E_DATE_EDIT_GET_PRIVATE (dedit);
+	dedit->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		dedit, E_TYPE_DATE_EDIT, EDateEditPrivate);
 
 	dedit->priv->show_date = TRUE;
 	dedit->priv->show_time = TRUE;
@@ -2209,10 +2206,12 @@ e_date_edit_time_is_valid	(EDateEdit	*dedit)
 
 /**
  * e_date_edit_have_time
- * Check if time is set, i.e. it isn't 'None'/empty. Date can be set in this case.
+ * @dedit: an #EDateEdit
  *
- * @param dedit an EDateEdit widget.
- * @return TRUE is time is set, FALSE otherwise.
+ * Check if time is set, i.e. it isn't 'None'/empty. Date can be set in
+ * this case.
+ *
+ * Returns: %TRUE is time is set, %FALSE otherwise.
  **/
 gboolean
 e_date_edit_have_time (EDateEdit *dedit)
